/* PublishingUI.c generated by valac 0.36.6, the Vala compiler
 * generated from PublishingUI.vala, do not modify */

/* Copyright 2016 Software Freedom Conservancy Inc.
 *
 * This software is licensed under the GNU Lesser General Public License
 * (version 2.1 or later).  See the COPYING file in this distribution.
 */

#include <glib.h>
#include <glib-object.h>
#include "shotwell-plugin-dev-1.0.h"
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <float.h>
#include <math.h>
#include <glib/gi18n-lib.h>
#include <gee.h>
#include <gdk/gdk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>


#define PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE (publishing_ui_concrete_dialog_pane_get_type ())
#define PUBLISHING_UI_CONCRETE_DIALOG_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, PublishingUIConcreteDialogPane))
#define PUBLISHING_UI_CONCRETE_DIALOG_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, PublishingUIConcreteDialogPaneClass))
#define PUBLISHING_UI_IS_CONCRETE_DIALOG_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE))
#define PUBLISHING_UI_IS_CONCRETE_DIALOG_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE))
#define PUBLISHING_UI_CONCRETE_DIALOG_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, PublishingUIConcreteDialogPaneClass))

typedef struct _PublishingUIConcreteDialogPane PublishingUIConcreteDialogPane;
typedef struct _PublishingUIConcreteDialogPaneClass PublishingUIConcreteDialogPaneClass;
typedef struct _PublishingUIConcreteDialogPanePrivate PublishingUIConcreteDialogPanePrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define PUBLISHING_UI_TYPE_STATIC_MESSAGE_PANE (publishing_ui_static_message_pane_get_type ())
#define PUBLISHING_UI_STATIC_MESSAGE_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_UI_TYPE_STATIC_MESSAGE_PANE, PublishingUIStaticMessagePane))
#define PUBLISHING_UI_STATIC_MESSAGE_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_UI_TYPE_STATIC_MESSAGE_PANE, PublishingUIStaticMessagePaneClass))
#define PUBLISHING_UI_IS_STATIC_MESSAGE_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_UI_TYPE_STATIC_MESSAGE_PANE))
#define PUBLISHING_UI_IS_STATIC_MESSAGE_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_UI_TYPE_STATIC_MESSAGE_PANE))
#define PUBLISHING_UI_STATIC_MESSAGE_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_UI_TYPE_STATIC_MESSAGE_PANE, PublishingUIStaticMessagePaneClass))

typedef struct _PublishingUIStaticMessagePane PublishingUIStaticMessagePane;
typedef struct _PublishingUIStaticMessagePaneClass PublishingUIStaticMessagePaneClass;
typedef struct _PublishingUIStaticMessagePanePrivate PublishingUIStaticMessagePanePrivate;

#define PUBLISHING_UI_TYPE_LOGIN_WELCOME_PANE (publishing_ui_login_welcome_pane_get_type ())
#define PUBLISHING_UI_LOGIN_WELCOME_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_UI_TYPE_LOGIN_WELCOME_PANE, PublishingUILoginWelcomePane))
#define PUBLISHING_UI_LOGIN_WELCOME_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_UI_TYPE_LOGIN_WELCOME_PANE, PublishingUILoginWelcomePaneClass))
#define PUBLISHING_UI_IS_LOGIN_WELCOME_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_UI_TYPE_LOGIN_WELCOME_PANE))
#define PUBLISHING_UI_IS_LOGIN_WELCOME_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_UI_TYPE_LOGIN_WELCOME_PANE))
#define PUBLISHING_UI_LOGIN_WELCOME_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_UI_TYPE_LOGIN_WELCOME_PANE, PublishingUILoginWelcomePaneClass))

typedef struct _PublishingUILoginWelcomePane PublishingUILoginWelcomePane;
typedef struct _PublishingUILoginWelcomePaneClass PublishingUILoginWelcomePaneClass;
typedef struct _PublishingUILoginWelcomePanePrivate PublishingUILoginWelcomePanePrivate;
enum  {
	PUBLISHING_UI_LOGIN_WELCOME_PANE_LOGIN_REQUESTED_SIGNAL,
	PUBLISHING_UI_LOGIN_WELCOME_PANE_LAST_SIGNAL
};
static guint publishing_ui_login_welcome_pane_signals[PUBLISHING_UI_LOGIN_WELCOME_PANE_LAST_SIGNAL] = {0};

#define PUBLISHING_UI_TYPE_PROGRESS_PANE (publishing_ui_progress_pane_get_type ())
#define PUBLISHING_UI_PROGRESS_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_UI_TYPE_PROGRESS_PANE, PublishingUIProgressPane))
#define PUBLISHING_UI_PROGRESS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_UI_TYPE_PROGRESS_PANE, PublishingUIProgressPaneClass))
#define PUBLISHING_UI_IS_PROGRESS_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_UI_TYPE_PROGRESS_PANE))
#define PUBLISHING_UI_IS_PROGRESS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_UI_TYPE_PROGRESS_PANE))
#define PUBLISHING_UI_PROGRESS_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_UI_TYPE_PROGRESS_PANE, PublishingUIProgressPaneClass))

typedef struct _PublishingUIProgressPane PublishingUIProgressPane;
typedef struct _PublishingUIProgressPaneClass PublishingUIProgressPaneClass;
typedef struct _PublishingUIProgressPanePrivate PublishingUIProgressPanePrivate;

#define PUBLISHING_UI_TYPE_SUCCESS_PANE (publishing_ui_success_pane_get_type ())
#define PUBLISHING_UI_SUCCESS_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_UI_TYPE_SUCCESS_PANE, PublishingUISuccessPane))
#define PUBLISHING_UI_SUCCESS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_UI_TYPE_SUCCESS_PANE, PublishingUISuccessPaneClass))
#define PUBLISHING_UI_IS_SUCCESS_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_UI_TYPE_SUCCESS_PANE))
#define PUBLISHING_UI_IS_SUCCESS_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_UI_TYPE_SUCCESS_PANE))
#define PUBLISHING_UI_SUCCESS_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_UI_TYPE_SUCCESS_PANE, PublishingUISuccessPaneClass))

typedef struct _PublishingUISuccessPane PublishingUISuccessPane;
typedef struct _PublishingUISuccessPaneClass PublishingUISuccessPaneClass;
typedef struct _PublishingUISuccessPanePrivate PublishingUISuccessPanePrivate;
#define _g_free0(var) (var = (g_free (var), NULL))

#define PUBLISHING_UI_TYPE_ACCOUNT_FETCH_WAIT_PANE (publishing_ui_account_fetch_wait_pane_get_type ())
#define PUBLISHING_UI_ACCOUNT_FETCH_WAIT_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_UI_TYPE_ACCOUNT_FETCH_WAIT_PANE, PublishingUIAccountFetchWaitPane))
#define PUBLISHING_UI_ACCOUNT_FETCH_WAIT_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_UI_TYPE_ACCOUNT_FETCH_WAIT_PANE, PublishingUIAccountFetchWaitPaneClass))
#define PUBLISHING_UI_IS_ACCOUNT_FETCH_WAIT_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_UI_TYPE_ACCOUNT_FETCH_WAIT_PANE))
#define PUBLISHING_UI_IS_ACCOUNT_FETCH_WAIT_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_UI_TYPE_ACCOUNT_FETCH_WAIT_PANE))
#define PUBLISHING_UI_ACCOUNT_FETCH_WAIT_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_UI_TYPE_ACCOUNT_FETCH_WAIT_PANE, PublishingUIAccountFetchWaitPaneClass))

typedef struct _PublishingUIAccountFetchWaitPane PublishingUIAccountFetchWaitPane;
typedef struct _PublishingUIAccountFetchWaitPaneClass PublishingUIAccountFetchWaitPaneClass;
typedef struct _PublishingUIAccountFetchWaitPanePrivate PublishingUIAccountFetchWaitPanePrivate;

#define PUBLISHING_UI_TYPE_LOGIN_WAIT_PANE (publishing_ui_login_wait_pane_get_type ())
#define PUBLISHING_UI_LOGIN_WAIT_PANE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_UI_TYPE_LOGIN_WAIT_PANE, PublishingUILoginWaitPane))
#define PUBLISHING_UI_LOGIN_WAIT_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_UI_TYPE_LOGIN_WAIT_PANE, PublishingUILoginWaitPaneClass))
#define PUBLISHING_UI_IS_LOGIN_WAIT_PANE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_UI_TYPE_LOGIN_WAIT_PANE))
#define PUBLISHING_UI_IS_LOGIN_WAIT_PANE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_UI_TYPE_LOGIN_WAIT_PANE))
#define PUBLISHING_UI_LOGIN_WAIT_PANE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_UI_TYPE_LOGIN_WAIT_PANE, PublishingUILoginWaitPaneClass))

typedef struct _PublishingUILoginWaitPane PublishingUILoginWaitPane;
typedef struct _PublishingUILoginWaitPaneClass PublishingUILoginWaitPaneClass;
typedef struct _PublishingUILoginWaitPanePrivate PublishingUILoginWaitPanePrivate;

#define PUBLISHING_UI_TYPE_PUBLISHING_DIALOG (publishing_ui_publishing_dialog_get_type ())
#define PUBLISHING_UI_PUBLISHING_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_UI_TYPE_PUBLISHING_DIALOG, PublishingUIPublishingDialog))
#define PUBLISHING_UI_PUBLISHING_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_UI_TYPE_PUBLISHING_DIALOG, PublishingUIPublishingDialogClass))
#define PUBLISHING_UI_IS_PUBLISHING_DIALOG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_UI_TYPE_PUBLISHING_DIALOG))
#define PUBLISHING_UI_IS_PUBLISHING_DIALOG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_UI_TYPE_PUBLISHING_DIALOG))
#define PUBLISHING_UI_PUBLISHING_DIALOG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_UI_TYPE_PUBLISHING_DIALOG, PublishingUIPublishingDialogClass))

typedef struct _PublishingUIPublishingDialog PublishingUIPublishingDialog;
typedef struct _PublishingUIPublishingDialogClass PublishingUIPublishingDialogClass;
typedef struct _PublishingUIPublishingDialogPrivate PublishingUIPublishingDialogPrivate;

#define PLUGINS_TYPE_STANDARD_HOST_INTERFACE (plugins_standard_host_interface_get_type ())
#define PLUGINS_STANDARD_HOST_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterface))
#define PLUGINS_STANDARD_HOST_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterfaceClass))
#define PLUGINS_IS_STANDARD_HOST_INTERFACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PLUGINS_TYPE_STANDARD_HOST_INTERFACE))
#define PLUGINS_IS_STANDARD_HOST_INTERFACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PLUGINS_TYPE_STANDARD_HOST_INTERFACE))
#define PLUGINS_STANDARD_HOST_INTERFACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PLUGINS_TYPE_STANDARD_HOST_INTERFACE, PluginsStandardHostInterfaceClass))

typedef struct _PluginsStandardHostInterface PluginsStandardHostInterface;
typedef struct _PluginsStandardHostInterfaceClass PluginsStandardHostInterfaceClass;

#define SPIT_PUBLISHING_TYPE_CONCRETE_PUBLISHING_HOST (spit_publishing_concrete_publishing_host_get_type ())
#define SPIT_PUBLISHING_CONCRETE_PUBLISHING_HOST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), SPIT_PUBLISHING_TYPE_CONCRETE_PUBLISHING_HOST, SpitPublishingConcretePublishingHost))
#define SPIT_PUBLISHING_CONCRETE_PUBLISHING_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), SPIT_PUBLISHING_TYPE_CONCRETE_PUBLISHING_HOST, SpitPublishingConcretePublishingHostClass))
#define SPIT_PUBLISHING_IS_CONCRETE_PUBLISHING_HOST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SPIT_PUBLISHING_TYPE_CONCRETE_PUBLISHING_HOST))
#define SPIT_PUBLISHING_IS_CONCRETE_PUBLISHING_HOST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), SPIT_PUBLISHING_TYPE_CONCRETE_PUBLISHING_HOST))
#define SPIT_PUBLISHING_CONCRETE_PUBLISHING_HOST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), SPIT_PUBLISHING_TYPE_CONCRETE_PUBLISHING_HOST, SpitPublishingConcretePublishingHostClass))

typedef struct _SpitPublishingConcretePublishingHost SpitPublishingConcretePublishingHost;
typedef struct _SpitPublishingConcretePublishingHostClass SpitPublishingConcretePublishingHostClass;

#define TYPE_DATA_OBJECT (data_object_get_type ())
#define DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_OBJECT, DataObject))
#define DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_OBJECT, DataObjectClass))
#define IS_DATA_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_OBJECT))
#define IS_DATA_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_OBJECT))
#define DATA_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_OBJECT, DataObjectClass))

typedef struct _DataObject DataObject;
typedef struct _DataObjectClass DataObjectClass;

#define TYPE_DATA_SOURCE (data_source_get_type ())
#define DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_DATA_SOURCE, DataSource))
#define DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_DATA_SOURCE, DataSourceClass))
#define IS_DATA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_DATA_SOURCE))
#define IS_DATA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_DATA_SOURCE))
#define DATA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_DATA_SOURCE, DataSourceClass))

typedef struct _DataSource DataSource;
typedef struct _DataSourceClass DataSourceClass;

#define TYPE_THUMBNAIL_SOURCE (thumbnail_source_get_type ())
#define THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSource))
#define THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))
#define IS_THUMBNAIL_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_THUMBNAIL_SOURCE))
#define IS_THUMBNAIL_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_THUMBNAIL_SOURCE))
#define THUMBNAIL_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_THUMBNAIL_SOURCE, ThumbnailSourceClass))

typedef struct _ThumbnailSource ThumbnailSource;
typedef struct _ThumbnailSourceClass ThumbnailSourceClass;

#define TYPE_MEDIA_SOURCE (media_source_get_type ())
#define MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MEDIA_SOURCE, MediaSource))
#define MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MEDIA_SOURCE, MediaSourceClass))
#define IS_MEDIA_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MEDIA_SOURCE))
#define IS_MEDIA_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MEDIA_SOURCE))
#define MEDIA_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MEDIA_SOURCE, MediaSourceClass))

typedef struct _MediaSource MediaSource;
typedef struct _MediaSourceClass MediaSourceClass;

#define TYPE_PAGE_WINDOW (page_window_get_type ())
#define PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PAGE_WINDOW, PageWindow))
#define PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PAGE_WINDOW, PageWindowClass))
#define IS_PAGE_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PAGE_WINDOW))
#define IS_PAGE_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PAGE_WINDOW))
#define PAGE_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PAGE_WINDOW, PageWindowClass))

typedef struct _PageWindow PageWindow;
typedef struct _PageWindowClass PageWindowClass;

#define TYPE_APP_WINDOW (app_window_get_type ())
#define APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_APP_WINDOW, AppWindow))
#define APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_APP_WINDOW, AppWindowClass))
#define IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_APP_WINDOW))
#define IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_APP_WINDOW))
#define APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_APP_WINDOW, AppWindowClass))

typedef struct _AppWindow AppWindow;
typedef struct _AppWindowClass AppWindowClass;

#define PUBLISHING_GLUE_TYPE_MEDIA_SOURCE_PUBLISHABLE_WRAPPER (publishing_glue_media_source_publishable_wrapper_get_type ())
#define PUBLISHING_GLUE_MEDIA_SOURCE_PUBLISHABLE_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), PUBLISHING_GLUE_TYPE_MEDIA_SOURCE_PUBLISHABLE_WRAPPER, PublishingGlueMediaSourcePublishableWrapper))
#define PUBLISHING_GLUE_MEDIA_SOURCE_PUBLISHABLE_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), PUBLISHING_GLUE_TYPE_MEDIA_SOURCE_PUBLISHABLE_WRAPPER, PublishingGlueMediaSourcePublishableWrapperClass))
#define PUBLISHING_GLUE_IS_MEDIA_SOURCE_PUBLISHABLE_WRAPPER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), PUBLISHING_GLUE_TYPE_MEDIA_SOURCE_PUBLISHABLE_WRAPPER))
#define PUBLISHING_GLUE_IS_MEDIA_SOURCE_PUBLISHABLE_WRAPPER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), PUBLISHING_GLUE_TYPE_MEDIA_SOURCE_PUBLISHABLE_WRAPPER))
#define PUBLISHING_GLUE_MEDIA_SOURCE_PUBLISHABLE_WRAPPER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), PUBLISHING_GLUE_TYPE_MEDIA_SOURCE_PUBLISHABLE_WRAPPER, PublishingGlueMediaSourcePublishableWrapperClass))

typedef struct _PublishingGlueMediaSourcePublishableWrapper PublishingGlueMediaSourcePublishableWrapper;
typedef struct _PublishingGlueMediaSourcePublishableWrapperClass PublishingGlueMediaSourcePublishableWrapperClass;

#define TYPE_CONFIGURATION_FACADE (configuration_facade_get_type ())
#define CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacade))
#define CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))
#define IS_CONFIGURATION_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIGURATION_FACADE))
#define IS_CONFIGURATION_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIGURATION_FACADE))
#define CONFIGURATION_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIGURATION_FACADE, ConfigurationFacadeClass))

typedef struct _ConfigurationFacade ConfigurationFacade;
typedef struct _ConfigurationFacadeClass ConfigurationFacadeClass;

#define CONFIG_TYPE_FACADE (config_facade_get_type ())
#define CONFIG_FACADE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), CONFIG_TYPE_FACADE, ConfigFacade))
#define CONFIG_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), CONFIG_TYPE_FACADE, ConfigFacadeClass))
#define CONFIG_IS_FACADE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CONFIG_TYPE_FACADE))
#define CONFIG_IS_FACADE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), CONFIG_TYPE_FACADE))
#define CONFIG_FACADE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), CONFIG_TYPE_FACADE, ConfigFacadeClass))

typedef struct _ConfigFacade ConfigFacade;
typedef struct _ConfigFacadeClass ConfigFacadeClass;
#define _g_timer_destroy0(var) ((var == NULL) ? NULL : (var = (g_timer_destroy (var), NULL)))

#define TYPE_PHOTO_SOURCE (photo_source_get_type ())
#define PHOTO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO_SOURCE, PhotoSource))
#define PHOTO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO_SOURCE, PhotoSourceClass))
#define IS_PHOTO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO_SOURCE))
#define IS_PHOTO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO_SOURCE))
#define PHOTO_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO_SOURCE, PhotoSourceClass))

typedef struct _PhotoSource PhotoSource;
typedef struct _PhotoSourceClass PhotoSourceClass;

#define TYPE_PHOTO (photo_get_type ())
#define PHOTO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PHOTO, Photo))
#define PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PHOTO, PhotoClass))
#define IS_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PHOTO))
#define IS_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PHOTO))
#define PHOTO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PHOTO, PhotoClass))

typedef struct _Photo Photo;
typedef struct _PhotoClass PhotoClass;

#define TYPE_LIBRARY_PHOTO (library_photo_get_type ())
#define LIBRARY_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_LIBRARY_PHOTO, LibraryPhoto))
#define LIBRARY_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_LIBRARY_PHOTO, LibraryPhotoClass))
#define IS_LIBRARY_PHOTO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_LIBRARY_PHOTO))
#define IS_LIBRARY_PHOTO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_LIBRARY_PHOTO))
#define LIBRARY_PHOTO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_LIBRARY_PHOTO, LibraryPhotoClass))

typedef struct _LibraryPhoto LibraryPhoto;
typedef struct _LibraryPhotoClass LibraryPhotoClass;

#define TYPE_VIDEO_SOURCE (video_source_get_type ())
#define VIDEO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIDEO_SOURCE, VideoSource))
#define VIDEO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIDEO_SOURCE, VideoSourceClass))
#define IS_VIDEO_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIDEO_SOURCE))
#define IS_VIDEO_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIDEO_SOURCE))
#define VIDEO_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIDEO_SOURCE, VideoSourceClass))

typedef struct _VideoSource VideoSource;
typedef struct _VideoSourceClass VideoSourceClass;

#define TYPE_VIDEO (video_get_type ())
#define VIDEO(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_VIDEO, Video))
#define VIDEO_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_VIDEO, VideoClass))
#define IS_VIDEO(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_VIDEO))
#define IS_VIDEO_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_VIDEO))
#define VIDEO_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_VIDEO, VideoClass))

typedef struct _Video Video;
typedef struct _VideoClass VideoClass;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _PublishingUIConcreteDialogPane {
	GObject parent_instance;
	PublishingUIConcreteDialogPanePrivate * priv;
	GtkBox* pane_widget;
	GtkBuilder* builder;
};

struct _PublishingUIConcreteDialogPaneClass {
	GObjectClass parent_class;
};

struct _PublishingUIStaticMessagePane {
	PublishingUIConcreteDialogPane parent_instance;
	PublishingUIStaticMessagePanePrivate * priv;
};

struct _PublishingUIStaticMessagePaneClass {
	PublishingUIConcreteDialogPaneClass parent_class;
};

struct _PublishingUIStaticMessagePanePrivate {
	GtkLabel* msg_label;
};

struct _PublishingUILoginWelcomePane {
	PublishingUIConcreteDialogPane parent_instance;
	PublishingUILoginWelcomePanePrivate * priv;
};

struct _PublishingUILoginWelcomePaneClass {
	PublishingUIConcreteDialogPaneClass parent_class;
};

struct _PublishingUILoginWelcomePanePrivate {
	GtkButton* login_button;
	GtkLabel* not_logged_in_label;
};

struct _PublishingUIProgressPane {
	PublishingUIConcreteDialogPane parent_instance;
	PublishingUIProgressPanePrivate * priv;
};

struct _PublishingUIProgressPaneClass {
	PublishingUIConcreteDialogPaneClass parent_class;
};

struct _PublishingUIProgressPanePrivate {
	GtkProgressBar* progress_bar;
};

struct _PublishingUISuccessPane {
	PublishingUIStaticMessagePane parent_instance;
	PublishingUISuccessPanePrivate * priv;
};

struct _PublishingUISuccessPaneClass {
	PublishingUIStaticMessagePaneClass parent_class;
};

struct _PublishingUIAccountFetchWaitPane {
	PublishingUIStaticMessagePane parent_instance;
	PublishingUIAccountFetchWaitPanePrivate * priv;
};

struct _PublishingUIAccountFetchWaitPaneClass {
	PublishingUIStaticMessagePaneClass parent_class;
};

struct _PublishingUILoginWaitPane {
	PublishingUIStaticMessagePane parent_instance;
	PublishingUILoginWaitPanePrivate * priv;
};

struct _PublishingUILoginWaitPaneClass {
	PublishingUIStaticMessagePaneClass parent_class;
};

struct _PublishingUIPublishingDialog {
	GtkDialog parent_instance;
	PublishingUIPublishingDialogPrivate * priv;
};

struct _PublishingUIPublishingDialogClass {
	GtkDialogClass parent_class;
};

struct _PublishingUIPublishingDialogPrivate {
	GtkListStore* service_selector_box_model;
	GtkComboBox* service_selector_box;
	GtkBox* central_area_layouter;
	GtkButton* close_cancel_button;
	SpitPublishingDialogPane* active_pane;
	SpitPublishingPublishable** publishables;
	gint publishables_length1;
	gint _publishables_size_;
	SpitPublishingConcretePublishingHost* host;
	SpitPluggableInfo info;
};


static gpointer publishing_ui_concrete_dialog_pane_parent_class = NULL;
static SpitPublishingDialogPaneIface * publishing_ui_concrete_dialog_pane_spit_publishing_dialog_pane_parent_iface = NULL;
static gpointer publishing_ui_static_message_pane_parent_class = NULL;
static gpointer publishing_ui_login_welcome_pane_parent_class = NULL;
static gpointer publishing_ui_progress_pane_parent_class = NULL;
static gpointer publishing_ui_success_pane_parent_class = NULL;
static gpointer publishing_ui_account_fetch_wait_pane_parent_class = NULL;
static gpointer publishing_ui_login_wait_pane_parent_class = NULL;
static gpointer publishing_ui_publishing_dialog_parent_class = NULL;
static PublishingUIPublishingDialog* publishing_ui_publishing_dialog_active_instance;
static PublishingUIPublishingDialog* publishing_ui_publishing_dialog_active_instance = NULL;
static GTimer* publishing_ui_publishing_dialog_since_last_start;
static GTimer* publishing_ui_publishing_dialog_since_last_start = NULL;
static gboolean publishing_ui_publishing_dialog_elapsed_is_valid;
static gboolean publishing_ui_publishing_dialog_elapsed_is_valid = FALSE;

GType publishing_ui_concrete_dialog_pane_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_UI_CONCRETE_DIALOG_PANE_DUMMY_PROPERTY
};
PublishingUIConcreteDialogPane* publishing_ui_concrete_dialog_pane_new (void);
PublishingUIConcreteDialogPane* publishing_ui_concrete_dialog_pane_construct (GType object_type);
GtkBuilder* app_window_create_builder (const gchar* glade_filename, void* user);
static GtkWidget* publishing_ui_concrete_dialog_pane_real_get_widget (SpitPublishingDialogPane* base);
static SpitPublishingDialogPaneGeometryOptions publishing_ui_concrete_dialog_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base);
static void publishing_ui_concrete_dialog_pane_real_on_pane_installed (SpitPublishingDialogPane* base);
static void publishing_ui_concrete_dialog_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base);
static void publishing_ui_concrete_dialog_pane_finalize (GObject * obj);
GType publishing_ui_static_message_pane_get_type (void) G_GNUC_CONST;
#define PUBLISHING_UI_STATIC_MESSAGE_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_UI_TYPE_STATIC_MESSAGE_PANE, PublishingUIStaticMessagePanePrivate))
enum  {
	PUBLISHING_UI_STATIC_MESSAGE_PANE_DUMMY_PROPERTY
};
PublishingUIStaticMessagePane* publishing_ui_static_message_pane_new (const gchar* message_string, gboolean enable_markup);
PublishingUIStaticMessagePane* publishing_ui_static_message_pane_construct (GType object_type, const gchar* message_string, gboolean enable_markup);
static void publishing_ui_static_message_pane_finalize (GObject * obj);
GType publishing_ui_login_welcome_pane_get_type (void) G_GNUC_CONST;
#define PUBLISHING_UI_LOGIN_WELCOME_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_UI_TYPE_LOGIN_WELCOME_PANE, PublishingUILoginWelcomePanePrivate))
enum  {
	PUBLISHING_UI_LOGIN_WELCOME_PANE_DUMMY_PROPERTY
};
PublishingUILoginWelcomePane* publishing_ui_login_welcome_pane_new (const gchar* service_welcome_message);
PublishingUILoginWelcomePane* publishing_ui_login_welcome_pane_construct (GType object_type, const gchar* service_welcome_message);
static void publishing_ui_login_welcome_pane_on_login_clicked (PublishingUILoginWelcomePane* self);
static void _publishing_ui_login_welcome_pane_on_login_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_ui_login_welcome_pane_finalize (GObject * obj);
GType publishing_ui_progress_pane_get_type (void) G_GNUC_CONST;
#define PUBLISHING_UI_PROGRESS_PANE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_UI_TYPE_PROGRESS_PANE, PublishingUIProgressPanePrivate))
enum  {
	PUBLISHING_UI_PROGRESS_PANE_DUMMY_PROPERTY
};
PublishingUIProgressPane* publishing_ui_progress_pane_new (void);
PublishingUIProgressPane* publishing_ui_progress_pane_construct (GType object_type);
void publishing_ui_progress_pane_set_text (PublishingUIProgressPane* self, const gchar* text);
void publishing_ui_progress_pane_set_progress (PublishingUIProgressPane* self, gdouble progress);
void publishing_ui_progress_pane_set_status (PublishingUIProgressPane* self, const gchar* status_text, gdouble progress);
static void publishing_ui_progress_pane_finalize (GObject * obj);
GType publishing_ui_success_pane_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_UI_SUCCESS_PANE_DUMMY_PROPERTY
};
PublishingUISuccessPane* publishing_ui_success_pane_new (SpitPublishingPublisherMediaType published_media, gint num_uploaded);
PublishingUISuccessPane* publishing_ui_success_pane_construct (GType object_type, SpitPublishingPublisherMediaType published_media, gint num_uploaded);
GType publishing_ui_account_fetch_wait_pane_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_UI_ACCOUNT_FETCH_WAIT_PANE_DUMMY_PROPERTY
};
PublishingUIAccountFetchWaitPane* publishing_ui_account_fetch_wait_pane_new (void);
PublishingUIAccountFetchWaitPane* publishing_ui_account_fetch_wait_pane_construct (GType object_type);
GType publishing_ui_login_wait_pane_get_type (void) G_GNUC_CONST;
enum  {
	PUBLISHING_UI_LOGIN_WAIT_PANE_DUMMY_PROPERTY
};
PublishingUILoginWaitPane* publishing_ui_login_wait_pane_new (void);
PublishingUILoginWaitPane* publishing_ui_login_wait_pane_construct (GType object_type);
GType publishing_ui_publishing_dialog_get_type (void) G_GNUC_CONST;
GType plugins_standard_host_interface_get_type (void) G_GNUC_CONST;
GType spit_publishing_concrete_publishing_host_get_type (void) G_GNUC_CONST;
#define PUBLISHING_UI_PUBLISHING_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), PUBLISHING_UI_TYPE_PUBLISHING_DIALOG, PublishingUIPublishingDialogPrivate))
enum  {
	PUBLISHING_UI_PUBLISHING_DIALOG_DUMMY_PROPERTY
};
#define PUBLISHING_UI_PUBLISHING_DIALOG_LARGE_WINDOW_WIDTH 860
#define PUBLISHING_UI_PUBLISHING_DIALOG_LARGE_WINDOW_HEIGHT 688
#define PUBLISHING_UI_PUBLISHING_DIALOG_COLOSSAL_WINDOW_WIDTH 1024
#define PUBLISHING_UI_PUBLISHING_DIALOG_COLOSSAL_WINDOW_HEIGHT 688
#define PUBLISHING_UI_PUBLISHING_DIALOG_STANDARD_WINDOW_WIDTH 632
#define PUBLISHING_UI_PUBLISHING_DIALOG_STANDARD_WINDOW_HEIGHT 540
#define PUBLISHING_UI_PUBLISHING_DIALOG_BORDER_REGION_WIDTH 16
#define PUBLISHING_UI_PUBLISHING_DIALOG_BORDER_REGION_HEIGHT 100
#define PUBLISHING_UI_PUBLISHING_DIALOG_STANDARD_CONTENT_LABEL_WIDTH 500
#define PUBLISHING_UI_PUBLISHING_DIALOG_STANDARD_ACTION_BUTTON_WIDTH 128
GType data_object_get_type (void) G_GNUC_CONST;
GType data_source_get_type (void) G_GNUC_CONST;
GType thumbnail_source_get_type (void) G_GNUC_CONST;
GType media_source_get_type (void) G_GNUC_CONST;
PublishingUIPublishingDialog* publishing_ui_publishing_dialog_new (GeeCollection* to_publish);
PublishingUIPublishingDialog* publishing_ui_publishing_dialog_construct (GType object_type, GeeCollection* to_publish);
GType page_window_get_type (void) G_GNUC_CONST;
GType app_window_get_type (void) G_GNUC_CONST;
AppWindow* app_window_get_instance (void);
static gboolean publishing_ui_publishing_dialog_on_window_close (PublishingUIPublishingDialog* self, GdkEventAny* evt);
static gboolean _publishing_ui_publishing_dialog_on_window_close_gtk_widget_delete_event (GtkWidget* _sender, GdkEventAny* event, gpointer self);
PublishingGlueMediaSourcePublishableWrapper* publishing_glue_media_source_publishable_wrapper_new (MediaSource* to_wrap);
PublishingGlueMediaSourcePublishableWrapper* publishing_glue_media_source_publishable_wrapper_construct (GType object_type, MediaSource* to_wrap);
GType publishing_glue_media_source_publishable_wrapper_get_type (void) G_GNUC_CONST;
static void _vala_array_add55 (SpitPublishingPublishable** * array, int* length, int* size, SpitPublishingPublishable* value);
GType configuration_facade_get_type (void) G_GNUC_CONST;
GType config_facade_get_type (void) G_GNUC_CONST;
ConfigFacade* config_facade_get_instance (void);
gchar* configuration_facade_get_last_used_service (ConfigurationFacade* self);
static SpitPublishingService** publishing_ui_publishing_dialog_load_services (gboolean has_photos, gboolean has_videos, int* result_length1);
GdkPixbuf* resources_get_icon (const gchar* name, gint scale);
#define RESOURCES_ICON_GENERIC_PLUGIN "generic-plugin.png"
#define RESOURCES_DEFAULT_ICON_SCALE 24
static void publishing_ui_publishing_dialog_on_service_changed (PublishingUIPublishingDialog* self);
static void _publishing_ui_publishing_dialog_on_service_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self);
static void publishing_ui_publishing_dialog_on_close_cancel_clicked (PublishingUIPublishingDialog* self);
static void _publishing_ui_publishing_dialog_on_close_cancel_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void publishing_ui_publishing_dialog_set_standard_window_mode (PublishingUIPublishingDialog* self);
static SpitPublishingService** publishing_ui_publishing_dialog_load_all_services (int* result_length1);
GeeCollection* plugins_get_pluggables_for_type (GType type, GCompareDataFunc compare_func, void* compare_func_target, GDestroyNotify compare_func_target_destroy_notify, gboolean include_disabled);
gchar* plugins_get_pluggable_module_id (SpitPluggable* needle);
static void _vala_array_add56 (SpitPublishingService** * array, int* length, int* size, SpitPublishingService* value);
static gint __lambda15_ (void* a, void* b);
gint utf8_cs_compare (void* a, void* b);
static gint ___lambda15____compar_fn_t (void* key1, void* key2);
static void _vala_array_add57 (SpitPublishingService** * array, int* length, int* size, SpitPublishingService* value);
static void _vala_array_add58 (SpitPublishingService** * array, int* length, int* size, SpitPublishingService* value);
static void _vala_array_add59 (SpitPublishingService** * array, int* length, int* size, SpitPublishingService* value);
void publishing_ui_publishing_dialog_go (GeeCollection* to_publish);
GType photo_source_get_type (void) G_GNUC_CONST;
GType photo_get_type (void) G_GNUC_CONST;
GType library_photo_get_type (void) G_GNUC_CONST;
GType video_source_get_type (void) G_GNUC_CONST;
GType video_get_type (void) G_GNUC_CONST;
void media_source_collection_filter_media (GeeCollection* media, GeeCollection* photos, GeeCollection* videos);
void app_window_error_message_with_title (const gchar* title, const gchar* message, GtkWindow* parent, gboolean should_escape);
gint publishing_ui_publishing_dialog_run (PublishingUIPublishingDialog* self);
void configuration_facade_set_last_used_service (ConfigurationFacade* self, const gchar* service_name);
SpitPublishingConcretePublishingHost* spit_publishing_concrete_publishing_host_new (SpitPublishingService* service, PublishingUIPublishingDialog* dialog, SpitPublishingPublishable** publishables, int publishables_length1);
SpitPublishingConcretePublishingHost* spit_publishing_concrete_publishing_host_construct (GType object_type, SpitPublishingService* service, PublishingUIPublishingDialog* dialog, SpitPublishingPublishable** publishables, int publishables_length1);
void spit_publishing_concrete_publishing_host_start_publishing (SpitPublishingConcretePublishingHost* self);
static void publishing_ui_publishing_dialog_set_large_window_mode (PublishingUIPublishingDialog* self);
static void publishing_ui_publishing_dialog_set_colossal_window_mode (PublishingUIPublishingDialog* self);
static void publishing_ui_publishing_dialog_set_free_sizable_window_mode (PublishingUIPublishingDialog* self);
static void publishing_ui_publishing_dialog_clear_free_sizable_window_mode (PublishingUIPublishingDialog* self);
SpitPublishingDialogPane* publishing_ui_publishing_dialog_get_active_pane (PublishingUIPublishingDialog* self);
void publishing_ui_publishing_dialog_set_close_button_mode (PublishingUIPublishingDialog* self);
void publishing_ui_publishing_dialog_set_cancel_button_mode (PublishingUIPublishingDialog* self);
void publishing_ui_publishing_dialog_lock_service (PublishingUIPublishingDialog* self);
void publishing_ui_publishing_dialog_unlock_service (PublishingUIPublishingDialog* self);
void publishing_ui_publishing_dialog_install_pane (PublishingUIPublishingDialog* self, SpitPublishingDialogPane* pane);
static void publishing_ui_publishing_dialog_finalize (GObject * obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


PublishingUIConcreteDialogPane* publishing_ui_concrete_dialog_pane_construct (GType object_type) {
	PublishingUIConcreteDialogPane * self = NULL;
	GtkBuilder* _tmp0_;
#line 13 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self = (PublishingUIConcreteDialogPane*) g_object_new (object_type, NULL);
#line 14 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = app_window_create_builder ("shotwell.ui", NULL);
#line 14 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->builder);
#line 14 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->builder = _tmp0_;
#line 13 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return self;
#line 557 "PublishingUI.c"
}


PublishingUIConcreteDialogPane* publishing_ui_concrete_dialog_pane_new (void) {
#line 13 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return publishing_ui_concrete_dialog_pane_construct (PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE);
#line 564 "PublishingUI.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 18 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return self ? g_object_ref (self) : NULL;
#line 571 "PublishingUI.c"
}


static GtkWidget* publishing_ui_concrete_dialog_pane_real_get_widget (SpitPublishingDialogPane* base) {
	PublishingUIConcreteDialogPane * self;
	GtkWidget* result = NULL;
	GtkBox* _tmp0_;
	GtkWidget* _tmp1_;
#line 17 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, PublishingUIConcreteDialogPane);
#line 18 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = self->pane_widget;
#line 18 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget));
#line 18 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	result = _tmp1_;
#line 18 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return result;
#line 590 "PublishingUI.c"
}


static SpitPublishingDialogPaneGeometryOptions publishing_ui_concrete_dialog_pane_real_get_preferred_geometry (SpitPublishingDialogPane* base) {
	PublishingUIConcreteDialogPane * self;
	SpitPublishingDialogPaneGeometryOptions result = 0;
#line 21 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, PublishingUIConcreteDialogPane);
#line 22 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	result = SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_NONE;
#line 22 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return result;
#line 603 "PublishingUI.c"
}


static void publishing_ui_concrete_dialog_pane_real_on_pane_installed (SpitPublishingDialogPane* base) {
	PublishingUIConcreteDialogPane * self;
#line 25 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, PublishingUIConcreteDialogPane);
#line 611 "PublishingUI.c"
}


static void publishing_ui_concrete_dialog_pane_real_on_pane_uninstalled (SpitPublishingDialogPane* base) {
	PublishingUIConcreteDialogPane * self;
#line 28 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (base, PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, PublishingUIConcreteDialogPane);
#line 619 "PublishingUI.c"
}


static void publishing_ui_concrete_dialog_pane_class_init (PublishingUIConcreteDialogPaneClass * klass) {
#line 9 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	publishing_ui_concrete_dialog_pane_parent_class = g_type_class_peek_parent (klass);
#line 9 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_ui_concrete_dialog_pane_finalize;
#line 628 "PublishingUI.c"
}


static void publishing_ui_concrete_dialog_pane_spit_publishing_dialog_pane_interface_init (SpitPublishingDialogPaneIface * iface) {
#line 9 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	publishing_ui_concrete_dialog_pane_spit_publishing_dialog_pane_parent_iface = g_type_interface_peek_parent (iface);
#line 9 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	iface->get_widget = (GtkWidget* (*) (SpitPublishingDialogPane *)) publishing_ui_concrete_dialog_pane_real_get_widget;
#line 9 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	iface->get_preferred_geometry = (SpitPublishingDialogPaneGeometryOptions (*) (SpitPublishingDialogPane *)) publishing_ui_concrete_dialog_pane_real_get_preferred_geometry;
#line 9 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	iface->on_pane_installed = (void (*) (SpitPublishingDialogPane *)) publishing_ui_concrete_dialog_pane_real_on_pane_installed;
#line 9 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	iface->on_pane_uninstalled = (void (*) (SpitPublishingDialogPane *)) publishing_ui_concrete_dialog_pane_real_on_pane_uninstalled;
#line 643 "PublishingUI.c"
}


static void publishing_ui_concrete_dialog_pane_instance_init (PublishingUIConcreteDialogPane * self) {
#line 10 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->pane_widget = NULL;
#line 11 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->builder = NULL;
#line 652 "PublishingUI.c"
}


static void publishing_ui_concrete_dialog_pane_finalize (GObject * obj) {
	PublishingUIConcreteDialogPane * self;
#line 9 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, PublishingUIConcreteDialogPane);
#line 10 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->pane_widget);
#line 11 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->builder);
#line 9 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	G_OBJECT_CLASS (publishing_ui_concrete_dialog_pane_parent_class)->finalize (obj);
#line 666 "PublishingUI.c"
}


GType publishing_ui_concrete_dialog_pane_get_type (void) {
	static volatile gsize publishing_ui_concrete_dialog_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_ui_concrete_dialog_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingUIConcreteDialogPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_ui_concrete_dialog_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingUIConcreteDialogPane), 0, (GInstanceInitFunc) publishing_ui_concrete_dialog_pane_instance_init, NULL };
		static const GInterfaceInfo spit_publishing_dialog_pane_info = { (GInterfaceInitFunc) publishing_ui_concrete_dialog_pane_spit_publishing_dialog_pane_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType publishing_ui_concrete_dialog_pane_type_id;
		publishing_ui_concrete_dialog_pane_type_id = g_type_register_static (G_TYPE_OBJECT, "PublishingUIConcreteDialogPane", &g_define_type_info, 0);
		g_type_add_interface_static (publishing_ui_concrete_dialog_pane_type_id, SPIT_PUBLISHING_TYPE_DIALOG_PANE, &spit_publishing_dialog_pane_info);
		g_once_init_leave (&publishing_ui_concrete_dialog_pane_type_id__volatile, publishing_ui_concrete_dialog_pane_type_id);
	}
	return publishing_ui_concrete_dialog_pane_type_id__volatile;
}


PublishingUIStaticMessagePane* publishing_ui_static_message_pane_construct (GType object_type, const gchar* message_string, gboolean enable_markup) {
	PublishingUIStaticMessagePane * self = NULL;
	GtkBuilder* _tmp0_;
	GObject* _tmp1_;
	GtkLabel* _tmp2_;
	GtkBuilder* _tmp3_;
	GObject* _tmp4_;
	GtkBox* _tmp5_;
	gboolean _tmp6_;
#line 35 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_val_if_fail (message_string != NULL, NULL);
#line 36 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self = (PublishingUIStaticMessagePane*) publishing_ui_concrete_dialog_pane_construct (object_type);
#line 37 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, PublishingUIConcreteDialogPane)->builder;
#line 37 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp1_ = gtk_builder_get_object (_tmp0_, "static_msg_label");
#line 37 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp1_) : NULL);
#line 37 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->msg_label);
#line 37 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv->msg_label = _tmp2_;
#line 38 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, PublishingUIConcreteDialogPane)->builder;
#line 38 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp4_ = gtk_builder_get_object (_tmp3_, "static_msg_pane_widget");
#line 38 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, gtk_box_get_type ()) ? ((GtkBox*) _tmp4_) : NULL);
#line 38 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, PublishingUIConcreteDialogPane)->pane_widget);
#line 38 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, PublishingUIConcreteDialogPane)->pane_widget = _tmp5_;
#line 40 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp6_ = enable_markup;
#line 40 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if (_tmp6_) {
#line 721 "PublishingUI.c"
		GtkLabel* _tmp7_;
		const gchar* _tmp8_;
		GtkLabel* _tmp9_;
		GtkLabel* _tmp10_;
#line 41 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp7_ = self->priv->msg_label;
#line 41 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp8_ = message_string;
#line 41 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_label_set_markup (_tmp7_, _tmp8_);
#line 42 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp9_ = self->priv->msg_label;
#line 42 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_label_set_line_wrap (_tmp9_, TRUE);
#line 43 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp10_ = self->priv->msg_label;
#line 43 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_label_set_use_markup (_tmp10_, TRUE);
#line 740 "PublishingUI.c"
	} else {
		GtkLabel* _tmp11_;
		const gchar* _tmp12_;
#line 45 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp11_ = self->priv->msg_label;
#line 45 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp12_ = message_string;
#line 45 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_label_set_label (_tmp11_, _tmp12_);
#line 750 "PublishingUI.c"
	}
#line 35 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return self;
#line 754 "PublishingUI.c"
}


PublishingUIStaticMessagePane* publishing_ui_static_message_pane_new (const gchar* message_string, gboolean enable_markup) {
#line 35 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return publishing_ui_static_message_pane_construct (PUBLISHING_UI_TYPE_STATIC_MESSAGE_PANE, message_string, enable_markup);
#line 761 "PublishingUI.c"
}


static void publishing_ui_static_message_pane_class_init (PublishingUIStaticMessagePaneClass * klass) {
#line 32 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	publishing_ui_static_message_pane_parent_class = g_type_class_peek_parent (klass);
#line 32 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_type_class_add_private (klass, sizeof (PublishingUIStaticMessagePanePrivate));
#line 32 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_ui_static_message_pane_finalize;
#line 772 "PublishingUI.c"
}


static void publishing_ui_static_message_pane_instance_init (PublishingUIStaticMessagePane * self) {
#line 32 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv = PUBLISHING_UI_STATIC_MESSAGE_PANE_GET_PRIVATE (self);
#line 33 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv->msg_label = NULL;
#line 781 "PublishingUI.c"
}


static void publishing_ui_static_message_pane_finalize (GObject * obj) {
	PublishingUIStaticMessagePane * self;
#line 32 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_UI_TYPE_STATIC_MESSAGE_PANE, PublishingUIStaticMessagePane);
#line 33 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->msg_label);
#line 32 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	G_OBJECT_CLASS (publishing_ui_static_message_pane_parent_class)->finalize (obj);
#line 793 "PublishingUI.c"
}


GType publishing_ui_static_message_pane_get_type (void) {
	static volatile gsize publishing_ui_static_message_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_ui_static_message_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingUIStaticMessagePaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_ui_static_message_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingUIStaticMessagePane), 0, (GInstanceInitFunc) publishing_ui_static_message_pane_instance_init, NULL };
		GType publishing_ui_static_message_pane_type_id;
		publishing_ui_static_message_pane_type_id = g_type_register_static (PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, "PublishingUIStaticMessagePane", &g_define_type_info, 0);
		g_once_init_leave (&publishing_ui_static_message_pane_type_id__volatile, publishing_ui_static_message_pane_type_id);
	}
	return publishing_ui_static_message_pane_type_id__volatile;
}


static void _publishing_ui_login_welcome_pane_on_login_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 62 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	publishing_ui_login_welcome_pane_on_login_clicked ((PublishingUILoginWelcomePane*) self);
#line 812 "PublishingUI.c"
}


PublishingUILoginWelcomePane* publishing_ui_login_welcome_pane_construct (GType object_type, const gchar* service_welcome_message) {
	PublishingUILoginWelcomePane * self = NULL;
	GtkBuilder* _tmp0_;
	GObject* _tmp1_;
	GtkBox* _tmp2_;
	GtkBuilder* _tmp3_;
	GObject* _tmp4_;
	GtkButton* _tmp5_;
	GtkBuilder* _tmp6_;
	GObject* _tmp7_;
	GtkLabel* _tmp8_;
	GtkButton* _tmp9_;
	GtkLabel* _tmp10_;
	GtkLabel* _tmp11_;
	const gchar* _tmp12_;
#line 56 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_val_if_fail (service_welcome_message != NULL, NULL);
#line 57 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self = (PublishingUILoginWelcomePane*) publishing_ui_concrete_dialog_pane_construct (object_type);
#line 58 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, PublishingUIConcreteDialogPane)->builder;
#line 58 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp1_ = gtk_builder_get_object (_tmp0_, "welcome_pane_widget");
#line 58 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, gtk_box_get_type ()) ? ((GtkBox*) _tmp1_) : NULL);
#line 58 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, PublishingUIConcreteDialogPane)->pane_widget);
#line 58 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, PublishingUIConcreteDialogPane)->pane_widget = _tmp2_;
#line 59 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, PublishingUIConcreteDialogPane)->builder;
#line 59 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp4_ = gtk_builder_get_object (_tmp3_, "login_button");
#line 59 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, gtk_button_get_type ()) ? ((GtkButton*) _tmp4_) : NULL);
#line 59 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->login_button);
#line 59 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv->login_button = _tmp5_;
#line 60 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp6_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, PublishingUIConcreteDialogPane)->builder;
#line 60 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp7_ = gtk_builder_get_object (_tmp6_, "not_logged_in_label");
#line 60 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp8_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, gtk_label_get_type ()) ? ((GtkLabel*) _tmp7_) : NULL);
#line 60 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->not_logged_in_label);
#line 60 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv->not_logged_in_label = _tmp8_;
#line 62 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp9_ = self->priv->login_button;
#line 62 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_signal_connect_object (_tmp9_, "clicked", (GCallback) _publishing_ui_login_welcome_pane_on_login_clicked_gtk_button_clicked, self, 0);
#line 63 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp10_ = self->priv->not_logged_in_label;
#line 63 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_label_set_use_markup (_tmp10_, TRUE);
#line 64 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp11_ = self->priv->not_logged_in_label;
#line 64 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp12_ = service_welcome_message;
#line 64 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_label_set_markup (_tmp11_, _tmp12_);
#line 56 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return self;
#line 881 "PublishingUI.c"
}


PublishingUILoginWelcomePane* publishing_ui_login_welcome_pane_new (const gchar* service_welcome_message) {
#line 56 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return publishing_ui_login_welcome_pane_construct (PUBLISHING_UI_TYPE_LOGIN_WELCOME_PANE, service_welcome_message);
#line 888 "PublishingUI.c"
}


static void publishing_ui_login_welcome_pane_on_login_clicked (PublishingUILoginWelcomePane* self) {
#line 67 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_if_fail (PUBLISHING_UI_IS_LOGIN_WELCOME_PANE (self));
#line 68 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_signal_emit (self, publishing_ui_login_welcome_pane_signals[PUBLISHING_UI_LOGIN_WELCOME_PANE_LOGIN_REQUESTED_SIGNAL], 0);
#line 897 "PublishingUI.c"
}


static void publishing_ui_login_welcome_pane_class_init (PublishingUILoginWelcomePaneClass * klass) {
#line 50 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	publishing_ui_login_welcome_pane_parent_class = g_type_class_peek_parent (klass);
#line 50 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_type_class_add_private (klass, sizeof (PublishingUILoginWelcomePanePrivate));
#line 50 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_ui_login_welcome_pane_finalize;
#line 50 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	publishing_ui_login_welcome_pane_signals[PUBLISHING_UI_LOGIN_WELCOME_PANE_LOGIN_REQUESTED_SIGNAL] = g_signal_new ("login-requested", PUBLISHING_UI_TYPE_LOGIN_WELCOME_PANE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 910 "PublishingUI.c"
}


static void publishing_ui_login_welcome_pane_instance_init (PublishingUILoginWelcomePane * self) {
#line 50 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv = PUBLISHING_UI_LOGIN_WELCOME_PANE_GET_PRIVATE (self);
#line 51 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv->login_button = NULL;
#line 52 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv->not_logged_in_label = NULL;
#line 921 "PublishingUI.c"
}


static void publishing_ui_login_welcome_pane_finalize (GObject * obj) {
	PublishingUILoginWelcomePane * self;
#line 50 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_UI_TYPE_LOGIN_WELCOME_PANE, PublishingUILoginWelcomePane);
#line 51 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->login_button);
#line 52 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->not_logged_in_label);
#line 50 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	G_OBJECT_CLASS (publishing_ui_login_welcome_pane_parent_class)->finalize (obj);
#line 935 "PublishingUI.c"
}


GType publishing_ui_login_welcome_pane_get_type (void) {
	static volatile gsize publishing_ui_login_welcome_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_ui_login_welcome_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingUILoginWelcomePaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_ui_login_welcome_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingUILoginWelcomePane), 0, (GInstanceInitFunc) publishing_ui_login_welcome_pane_instance_init, NULL };
		GType publishing_ui_login_welcome_pane_type_id;
		publishing_ui_login_welcome_pane_type_id = g_type_register_static (PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, "PublishingUILoginWelcomePane", &g_define_type_info, 0);
		g_once_init_leave (&publishing_ui_login_welcome_pane_type_id__volatile, publishing_ui_login_welcome_pane_type_id);
	}
	return publishing_ui_login_welcome_pane_type_id__volatile;
}


PublishingUIProgressPane* publishing_ui_progress_pane_construct (GType object_type) {
	PublishingUIProgressPane * self = NULL;
	GtkBuilder* _tmp0_;
	GObject* _tmp1_;
	GtkBox* _tmp2_;
	GtkBuilder* _tmp3_;
	GObject* _tmp4_;
	GtkProgressBar* _tmp5_;
#line 76 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self = (PublishingUIProgressPane*) publishing_ui_concrete_dialog_pane_construct (object_type);
#line 77 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, PublishingUIConcreteDialogPane)->builder;
#line 77 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp1_ = gtk_builder_get_object (_tmp0_, "progress_pane_widget");
#line 77 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp2_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_box_get_type (), GtkBox));
#line 77 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, PublishingUIConcreteDialogPane)->pane_widget);
#line 77 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, PublishingUIConcreteDialogPane)->pane_widget = _tmp2_;
#line 78 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp3_ = G_TYPE_CHECK_INSTANCE_CAST (self, PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, PublishingUIConcreteDialogPane)->builder;
#line 78 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp4_ = gtk_builder_get_object (_tmp3_, "publishing_progress_bar");
#line 78 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp4_, gtk_progress_bar_get_type (), GtkProgressBar));
#line 78 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->progress_bar);
#line 78 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv->progress_bar = _tmp5_;
#line 75 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return self;
#line 983 "PublishingUI.c"
}


PublishingUIProgressPane* publishing_ui_progress_pane_new (void) {
#line 75 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return publishing_ui_progress_pane_construct (PUBLISHING_UI_TYPE_PROGRESS_PANE);
#line 990 "PublishingUI.c"
}


void publishing_ui_progress_pane_set_text (PublishingUIProgressPane* self, const gchar* text) {
	GtkProgressBar* _tmp0_;
	const gchar* _tmp1_;
#line 81 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_if_fail (PUBLISHING_UI_IS_PROGRESS_PANE (self));
#line 81 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_if_fail (text != NULL);
#line 82 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = self->priv->progress_bar;
#line 82 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp1_ = text;
#line 82 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_progress_bar_set_text (_tmp0_, _tmp1_);
#line 1007 "PublishingUI.c"
}


void publishing_ui_progress_pane_set_progress (PublishingUIProgressPane* self, gdouble progress) {
	GtkProgressBar* _tmp0_;
	gdouble _tmp1_;
#line 85 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_if_fail (PUBLISHING_UI_IS_PROGRESS_PANE (self));
#line 86 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = self->priv->progress_bar;
#line 86 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp1_ = progress;
#line 86 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_progress_bar_set_fraction (_tmp0_, _tmp1_);
#line 1022 "PublishingUI.c"
}


void publishing_ui_progress_pane_set_status (PublishingUIProgressPane* self, const gchar* status_text, gdouble progress) {
	const gchar* _tmp0_;
	GtkProgressBar* _tmp1_;
	const gchar* _tmp2_;
	gdouble _tmp5_;
#line 89 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_if_fail (PUBLISHING_UI_IS_PROGRESS_PANE (self));
#line 89 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_if_fail (status_text != NULL);
#line 90 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = status_text;
#line 90 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp1_ = self->priv->progress_bar;
#line 90 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp2_ = gtk_progress_bar_get_text (_tmp1_);
#line 90 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if (g_strcmp0 (_tmp0_, _tmp2_) != 0) {
#line 1043 "PublishingUI.c"
		GtkProgressBar* _tmp3_;
		const gchar* _tmp4_;
#line 91 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp3_ = self->priv->progress_bar;
#line 91 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp4_ = status_text;
#line 91 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_progress_bar_set_text (_tmp3_, _tmp4_);
#line 1052 "PublishingUI.c"
	}
#line 93 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp5_ = progress;
#line 93 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	publishing_ui_progress_pane_set_progress (self, _tmp5_);
#line 1058 "PublishingUI.c"
}


static void publishing_ui_progress_pane_class_init (PublishingUIProgressPaneClass * klass) {
#line 72 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	publishing_ui_progress_pane_parent_class = g_type_class_peek_parent (klass);
#line 72 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_type_class_add_private (klass, sizeof (PublishingUIProgressPanePrivate));
#line 72 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_ui_progress_pane_finalize;
#line 1069 "PublishingUI.c"
}


static void publishing_ui_progress_pane_instance_init (PublishingUIProgressPane * self) {
#line 72 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv = PUBLISHING_UI_PROGRESS_PANE_GET_PRIVATE (self);
#line 73 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv->progress_bar = NULL;
#line 1078 "PublishingUI.c"
}


static void publishing_ui_progress_pane_finalize (GObject * obj) {
	PublishingUIProgressPane * self;
#line 72 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_UI_TYPE_PROGRESS_PANE, PublishingUIProgressPane);
#line 73 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->progress_bar);
#line 72 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	G_OBJECT_CLASS (publishing_ui_progress_pane_parent_class)->finalize (obj);
#line 1090 "PublishingUI.c"
}


GType publishing_ui_progress_pane_get_type (void) {
	static volatile gsize publishing_ui_progress_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_ui_progress_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingUIProgressPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_ui_progress_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingUIProgressPane), 0, (GInstanceInitFunc) publishing_ui_progress_pane_instance_init, NULL };
		GType publishing_ui_progress_pane_type_id;
		publishing_ui_progress_pane_type_id = g_type_register_static (PUBLISHING_UI_TYPE_CONCRETE_DIALOG_PANE, "PublishingUIProgressPane", &g_define_type_info, 0);
		g_once_init_leave (&publishing_ui_progress_pane_type_id__volatile, publishing_ui_progress_pane_type_id);
	}
	return publishing_ui_progress_pane_type_id__volatile;
}


PublishingUISuccessPane* publishing_ui_success_pane_construct (GType object_type, SpitPublishingPublisherMediaType published_media, gint num_uploaded) {
	PublishingUISuccessPane * self = NULL;
	gchar* message_string = NULL;
	SpitPublishingPublisherMediaType _tmp0_;
	const gchar* _tmp8_;
#line 99 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	message_string = NULL;
#line 103 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = published_media;
#line 103 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if (_tmp0_ == SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) {
#line 1117 "PublishingUI.c"
		gint _tmp1_;
		gchar* _tmp2_;
#line 104 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp1_ = num_uploaded;
#line 104 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp2_ = g_strdup (ngettext ("The selected video was successfully published.", "The selected videos were successfully published.", (gulong) _tmp1_));
#line 104 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_g_free0 (message_string);
#line 104 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		message_string = _tmp2_;
#line 1128 "PublishingUI.c"
	} else {
		SpitPublishingPublisherMediaType _tmp3_;
#line 108 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp3_ = published_media;
#line 108 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		if (_tmp3_ == SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO) {
#line 1135 "PublishingUI.c"
			gint _tmp4_;
			gchar* _tmp5_;
#line 109 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp4_ = num_uploaded;
#line 109 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp5_ = g_strdup (ngettext ("The selected photo was successfully published.", "The selected photos were successfully published.", (gulong) _tmp4_));
#line 109 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_g_free0 (message_string);
#line 109 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			message_string = _tmp5_;
#line 1146 "PublishingUI.c"
		} else {
			SpitPublishingPublisherMediaType _tmp6_;
#line 113 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp6_ = published_media;
#line 113 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			if (_tmp6_ == (SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO | SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO)) {
#line 1153 "PublishingUI.c"
				gchar* _tmp7_;
#line 115 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_tmp7_ = g_strdup (_ ("The selected photos/videos were successfully published."));
#line 115 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_g_free0 (message_string);
#line 115 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				message_string = _tmp7_;
#line 1161 "PublishingUI.c"
			} else {
#line 118 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				g_assert_not_reached ();
#line 1165 "PublishingUI.c"
			}
		}
	}
#line 121 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp8_ = message_string;
#line 121 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self = (PublishingUISuccessPane*) publishing_ui_static_message_pane_construct (object_type, _tmp8_, FALSE);
#line 98 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_free0 (message_string);
#line 98 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return self;
#line 1177 "PublishingUI.c"
}


PublishingUISuccessPane* publishing_ui_success_pane_new (SpitPublishingPublisherMediaType published_media, gint num_uploaded) {
#line 98 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return publishing_ui_success_pane_construct (PUBLISHING_UI_TYPE_SUCCESS_PANE, published_media, num_uploaded);
#line 1184 "PublishingUI.c"
}


static void publishing_ui_success_pane_class_init (PublishingUISuccessPaneClass * klass) {
#line 97 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	publishing_ui_success_pane_parent_class = g_type_class_peek_parent (klass);
#line 1191 "PublishingUI.c"
}


static void publishing_ui_success_pane_instance_init (PublishingUISuccessPane * self) {
}


GType publishing_ui_success_pane_get_type (void) {
	static volatile gsize publishing_ui_success_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_ui_success_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingUISuccessPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_ui_success_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingUISuccessPane), 0, (GInstanceInitFunc) publishing_ui_success_pane_instance_init, NULL };
		GType publishing_ui_success_pane_type_id;
		publishing_ui_success_pane_type_id = g_type_register_static (PUBLISHING_UI_TYPE_STATIC_MESSAGE_PANE, "PublishingUISuccessPane", &g_define_type_info, 0);
		g_once_init_leave (&publishing_ui_success_pane_type_id__volatile, publishing_ui_success_pane_type_id);
	}
	return publishing_ui_success_pane_type_id__volatile;
}


PublishingUIAccountFetchWaitPane* publishing_ui_account_fetch_wait_pane_construct (GType object_type) {
	PublishingUIAccountFetchWaitPane * self = NULL;
#line 127 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self = (PublishingUIAccountFetchWaitPane*) publishing_ui_static_message_pane_construct (object_type, _ ("Fetching account information…"), FALSE);
#line 126 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return self;
#line 1217 "PublishingUI.c"
}


PublishingUIAccountFetchWaitPane* publishing_ui_account_fetch_wait_pane_new (void) {
#line 126 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return publishing_ui_account_fetch_wait_pane_construct (PUBLISHING_UI_TYPE_ACCOUNT_FETCH_WAIT_PANE);
#line 1224 "PublishingUI.c"
}


static void publishing_ui_account_fetch_wait_pane_class_init (PublishingUIAccountFetchWaitPaneClass * klass) {
#line 125 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	publishing_ui_account_fetch_wait_pane_parent_class = g_type_class_peek_parent (klass);
#line 1231 "PublishingUI.c"
}


static void publishing_ui_account_fetch_wait_pane_instance_init (PublishingUIAccountFetchWaitPane * self) {
}


GType publishing_ui_account_fetch_wait_pane_get_type (void) {
	static volatile gsize publishing_ui_account_fetch_wait_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_ui_account_fetch_wait_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingUIAccountFetchWaitPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_ui_account_fetch_wait_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingUIAccountFetchWaitPane), 0, (GInstanceInitFunc) publishing_ui_account_fetch_wait_pane_instance_init, NULL };
		GType publishing_ui_account_fetch_wait_pane_type_id;
		publishing_ui_account_fetch_wait_pane_type_id = g_type_register_static (PUBLISHING_UI_TYPE_STATIC_MESSAGE_PANE, "PublishingUIAccountFetchWaitPane", &g_define_type_info, 0);
		g_once_init_leave (&publishing_ui_account_fetch_wait_pane_type_id__volatile, publishing_ui_account_fetch_wait_pane_type_id);
	}
	return publishing_ui_account_fetch_wait_pane_type_id__volatile;
}


PublishingUILoginWaitPane* publishing_ui_login_wait_pane_construct (GType object_type) {
	PublishingUILoginWaitPane * self = NULL;
#line 133 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self = (PublishingUILoginWaitPane*) publishing_ui_static_message_pane_construct (object_type, _ ("Logging in…"), FALSE);
#line 132 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return self;
#line 1257 "PublishingUI.c"
}


PublishingUILoginWaitPane* publishing_ui_login_wait_pane_new (void) {
#line 132 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return publishing_ui_login_wait_pane_construct (PUBLISHING_UI_TYPE_LOGIN_WAIT_PANE);
#line 1264 "PublishingUI.c"
}


static void publishing_ui_login_wait_pane_class_init (PublishingUILoginWaitPaneClass * klass) {
#line 131 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	publishing_ui_login_wait_pane_parent_class = g_type_class_peek_parent (klass);
#line 1271 "PublishingUI.c"
}


static void publishing_ui_login_wait_pane_instance_init (PublishingUILoginWaitPane * self) {
}


GType publishing_ui_login_wait_pane_get_type (void) {
	static volatile gsize publishing_ui_login_wait_pane_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_ui_login_wait_pane_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingUILoginWaitPaneClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_ui_login_wait_pane_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingUILoginWaitPane), 0, (GInstanceInitFunc) publishing_ui_login_wait_pane_instance_init, NULL };
		GType publishing_ui_login_wait_pane_type_id;
		publishing_ui_login_wait_pane_type_id = g_type_register_static (PUBLISHING_UI_TYPE_STATIC_MESSAGE_PANE, "PublishingUILoginWaitPane", &g_define_type_info, 0);
		g_once_init_leave (&publishing_ui_login_wait_pane_type_id__volatile, publishing_ui_login_wait_pane_type_id);
	}
	return publishing_ui_login_wait_pane_type_id__volatile;
}


static gboolean _publishing_ui_publishing_dialog_on_window_close_gtk_widget_delete_event (GtkWidget* _sender, GdkEventAny* event, gpointer self) {
	gboolean result;
	result = publishing_ui_publishing_dialog_on_window_close ((PublishingUIPublishingDialog*) self, event);
#line 173 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return result;
#line 1296 "PublishingUI.c"
}


static void _vala_array_add55 (SpitPublishingPublishable** * array, int* length, int* size, SpitPublishingPublishable* value) {
#line 188 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if ((*length) == (*size)) {
#line 188 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 188 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		*array = g_renew (SpitPublishingPublishable*, *array, (*size) + 1);
#line 1307 "PublishingUI.c"
	}
#line 188 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	(*array)[(*length)++] = value;
#line 188 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	(*array)[*length] = NULL;
#line 1313 "PublishingUI.c"
}


static void _publishing_ui_publishing_dialog_on_service_changed_gtk_combo_box_changed (GtkComboBox* _sender, gpointer self) {
#line 254 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	publishing_ui_publishing_dialog_on_service_changed ((PublishingUIPublishingDialog*) self);
#line 1320 "PublishingUI.c"
}


static void _publishing_ui_publishing_dialog_on_close_cancel_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 306 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	publishing_ui_publishing_dialog_on_close_cancel_clicked ((PublishingUIPublishingDialog*) self);
#line 1327 "PublishingUI.c"
}


PublishingUIPublishingDialog* publishing_ui_publishing_dialog_construct (GType object_type, GeeCollection* to_publish) {
	PublishingUIPublishingDialog * self = NULL;
	GeeCollection* _tmp0_;
	gint _tmp1_;
	gint _tmp2_;
	gboolean use_header = FALSE;
	GtkSettings* _tmp3_;
	gint _tmp4_ = 0;
	gboolean _tmp5_;
	gboolean _tmp6_;
	AppWindow* _tmp8_;
	AppWindow* _tmp9_;
	SpitPublishingPublishable** _tmp10_;
	gboolean has_photos = FALSE;
	gboolean has_videos = FALSE;
	gchar* title = NULL;
	gchar* label = NULL;
	gboolean _tmp26_ = FALSE;
	gboolean _tmp27_;
	const gchar* _tmp38_;
	GtkListStore* _tmp39_;
	GtkListStore* _tmp40_;
	GtkComboBox* _tmp41_;
	GtkCellRendererPixbuf* renderer_pix = NULL;
	GtkCellRendererPixbuf* _tmp42_;
	GtkComboBox* _tmp43_;
	GtkCellRendererPixbuf* _tmp44_;
	GtkComboBox* _tmp45_;
	GtkCellRendererPixbuf* _tmp46_;
	GtkCellRendererText* renderer_text = NULL;
	GtkCellRendererText* _tmp47_;
	GtkComboBox* _tmp48_;
	GtkCellRendererText* _tmp49_;
	GtkComboBox* _tmp50_;
	GtkCellRendererText* _tmp51_;
	GtkComboBox* _tmp52_;
	gchar* last_used_service = NULL;
	ConfigFacade* _tmp53_;
	ConfigFacade* _tmp54_;
	gchar* _tmp55_;
	gchar* _tmp56_;
	SpitPublishingService** loaded_services = NULL;
	gboolean _tmp57_;
	gboolean _tmp58_;
	gint _tmp59_;
	SpitPublishingService** _tmp60_;
	gint loaded_services_length1;
	gint _loaded_services_size_;
	GtkTreeIter iter = {0};
	SpitPublishingService** _tmp61_;
	gint _tmp61__length1;
	GtkComboBox* _tmp99_;
	gboolean _tmp100_;
	GtkBox* _tmp130_;
	GtkBox* _tmp131_;
	GtkBox* _tmp132_;
	gboolean _tmp133_;
	GtkButton* _tmp142_;
#line 161 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_val_if_fail (GEE_IS_COLLECTION (to_publish), NULL);
#line 162 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = to_publish;
#line 162 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp1_ = gee_collection_get_size (_tmp0_);
#line 162 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp2_ = _tmp1_;
#line 162 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_vala_assert (_tmp2_ > 0, "to_publish.size > 0");
#line 164 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	use_header = FALSE;
#line 165 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp3_ = gtk_settings_get_default ();
#line 165 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_object_get (G_TYPE_CHECK_INSTANCE_CAST (_tmp3_, G_TYPE_OBJECT, GObject), "gtk-dialogs-use-header", &use_header, NULL);
#line 166 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp5_ = use_header;
#line 166 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if (_tmp5_) {
#line 166 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp4_ = 1;
#line 1411 "PublishingUI.c"
	} else {
#line 166 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp4_ = 0;
#line 1415 "PublishingUI.c"
	}
#line 166 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self = (PublishingUIPublishingDialog*) g_object_new (object_type, "use-header-bar", _tmp4_, NULL);
#line 167 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp6_ = use_header;
#line 167 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if (_tmp6_) {
#line 1423 "PublishingUI.c"
		GtkWidget* _tmp7_;
#line 168 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp7_ = gtk_dialog_get_header_bar (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 168 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_header_bar_set_show_close_button (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, gtk_header_bar_get_type (), GtkHeaderBar), FALSE);
#line 1429 "PublishingUI.c"
	}
#line 170 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 171 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_window_set_modal (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), TRUE);
#line 172 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp8_ = app_window_get_instance ();
#line 172 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp9_ = _tmp8_;
#line 172 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_window_set_transient_for (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, gtk_window_get_type (), GtkWindow));
#line 172 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (_tmp9_);
#line 173 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_signal_connect_object (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), "delete-event", (GCallback) _publishing_ui_publishing_dialog_on_window_close_gtk_widget_delete_event, self, 0);
#line 175 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp10_ = g_new0 (SpitPublishingPublishable*, 0 + 1);
#line 175 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv->publishables = (_vala_array_free (self->priv->publishables, self->priv->publishables_length1, (GDestroyNotify) g_object_unref), NULL);
#line 175 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv->publishables = _tmp10_;
#line 175 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv->publishables_length1 = 0;
#line 175 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv->_publishables_size_ = self->priv->publishables_length1;
#line 176 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	has_photos = FALSE;
#line 177 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	has_videos = FALSE;
#line 1459 "PublishingUI.c"
	{
		GeeIterator* _media_it = NULL;
		GeeCollection* _tmp11_;
		GeeIterator* _tmp12_;
#line 178 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp11_ = to_publish;
#line 178 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp12_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp11_, GEE_TYPE_ITERABLE, GeeIterable));
#line 178 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_media_it = _tmp12_;
#line 178 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		while (TRUE) {
#line 1472 "PublishingUI.c"
			GeeIterator* _tmp13_;
			gboolean _tmp14_;
			MediaSource* media = NULL;
			GeeIterator* _tmp15_;
			gpointer _tmp16_;
			SpitPublishingPublishable* publishable = NULL;
			MediaSource* _tmp17_;
			PublishingGlueMediaSourcePublishableWrapper* _tmp18_;
			SpitPublishingPublishable* _tmp19_;
			SpitPublishingPublisherMediaType _tmp20_;
			SpitPublishingPublishable** _tmp23_;
			gint _tmp23__length1;
			SpitPublishingPublishable* _tmp24_;
			SpitPublishingPublishable* _tmp25_;
#line 178 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp13_ = _media_it;
#line 178 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp14_ = gee_iterator_next (_tmp13_);
#line 178 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			if (!_tmp14_) {
#line 178 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				break;
#line 1495 "PublishingUI.c"
			}
#line 178 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp15_ = _media_it;
#line 178 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp16_ = gee_iterator_get (_tmp15_);
#line 178 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			media = (MediaSource*) _tmp16_;
#line 179 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp17_ = media;
#line 179 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp18_ = publishing_glue_media_source_publishable_wrapper_new (_tmp17_);
#line 179 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			publishable = G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, SPIT_PUBLISHING_TYPE_PUBLISHABLE, SpitPublishingPublishable);
#line 181 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp19_ = publishable;
#line 181 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp20_ = spit_publishing_publishable_get_media_type (_tmp19_);
#line 181 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			if (_tmp20_ == SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO) {
#line 182 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				has_photos = TRUE;
#line 1517 "PublishingUI.c"
			} else {
				SpitPublishingPublishable* _tmp21_;
				SpitPublishingPublisherMediaType _tmp22_;
#line 183 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_tmp21_ = publishable;
#line 183 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_tmp22_ = spit_publishing_publishable_get_media_type (_tmp21_);
#line 183 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				if (_tmp22_ == SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) {
#line 184 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					has_videos = TRUE;
#line 1529 "PublishingUI.c"
				} else {
#line 186 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					g_assert_not_reached ();
#line 1533 "PublishingUI.c"
				}
			}
#line 188 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp23_ = self->priv->publishables;
#line 188 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp23__length1 = self->priv->publishables_length1;
#line 188 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp24_ = publishable;
#line 188 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp25_ = _g_object_ref0 (_tmp24_);
#line 188 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_vala_array_add55 (&self->priv->publishables, &self->priv->publishables_length1, &self->priv->_publishables_size_, _tmp25_);
#line 178 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_g_object_unref0 (publishable);
#line 178 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_g_object_unref0 (media);
#line 1550 "PublishingUI.c"
		}
#line 178 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_g_object_unref0 (_media_it);
#line 1554 "PublishingUI.c"
	}
#line 191 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	title = NULL;
#line 192 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	label = NULL;
#line 194 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp27_ = has_photos;
#line 194 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if (_tmp27_) {
#line 1564 "PublishingUI.c"
		gboolean _tmp28_;
#line 194 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp28_ = has_videos;
#line 194 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp26_ = !_tmp28_;
#line 1570 "PublishingUI.c"
	} else {
#line 194 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp26_ = FALSE;
#line 1574 "PublishingUI.c"
	}
#line 194 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if (_tmp26_) {
#line 1578 "PublishingUI.c"
		gchar* _tmp29_;
		gchar* _tmp30_;
#line 195 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp29_ = g_strdup (_ ("Publish Photos"));
#line 195 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_g_free0 (title);
#line 195 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		title = _tmp29_;
#line 196 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp30_ = g_strdup (_ ("Publish photos _to:"));
#line 196 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_g_free0 (label);
#line 196 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		label = _tmp30_;
#line 1593 "PublishingUI.c"
	} else {
		gboolean _tmp31_ = FALSE;
		gboolean _tmp32_;
#line 197 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp32_ = has_photos;
#line 197 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		if (!_tmp32_) {
#line 1601 "PublishingUI.c"
			gboolean _tmp33_;
#line 197 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp33_ = has_videos;
#line 197 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp31_ = _tmp33_;
#line 1607 "PublishingUI.c"
		} else {
#line 197 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp31_ = FALSE;
#line 1611 "PublishingUI.c"
		}
#line 197 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		if (_tmp31_) {
#line 1615 "PublishingUI.c"
			gchar* _tmp34_;
			gchar* _tmp35_;
#line 198 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp34_ = g_strdup (_ ("Publish Videos"));
#line 198 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_g_free0 (title);
#line 198 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			title = _tmp34_;
#line 199 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp35_ = g_strdup (_ ("Publish videos _to"));
#line 199 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_g_free0 (label);
#line 199 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			label = _tmp35_;
#line 1630 "PublishingUI.c"
		} else {
			gchar* _tmp36_;
			gchar* _tmp37_;
#line 201 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp36_ = g_strdup (_ ("Publish Photos and Videos"));
#line 201 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_g_free0 (title);
#line 201 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			title = _tmp36_;
#line 202 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp37_ = g_strdup (_ ("Publish photos and videos _to"));
#line 202 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_g_free0 (label);
#line 202 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			label = _tmp37_;
#line 1646 "PublishingUI.c"
		}
	}
#line 204 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp38_ = title;
#line 204 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_window_set_title (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), _tmp38_);
#line 206 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp39_ = gtk_list_store_new (2, gdk_pixbuf_get_type (), G_TYPE_STRING, -1);
#line 206 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->service_selector_box_model);
#line 206 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv->service_selector_box_model = _tmp39_;
#line 207 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp40_ = self->priv->service_selector_box_model;
#line 207 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp41_ = (GtkComboBox*) gtk_combo_box_new_with_model (G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, GTK_TYPE_TREE_MODEL, GtkTreeModel));
#line 207 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_object_ref_sink (_tmp41_);
#line 207 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->service_selector_box);
#line 207 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv->service_selector_box = _tmp41_;
#line 209 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp42_ = (GtkCellRendererPixbuf*) gtk_cell_renderer_pixbuf_new ();
#line 209 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_object_ref_sink (_tmp42_);
#line 209 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	renderer_pix = _tmp42_;
#line 210 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp43_ = self->priv->service_selector_box;
#line 210 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp44_ = renderer_pix;
#line 210 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_cell_layout_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp43_, GTK_TYPE_CELL_LAYOUT, GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp44_, gtk_cell_renderer_get_type (), GtkCellRenderer), TRUE);
#line 211 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp45_ = self->priv->service_selector_box;
#line 211 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp46_ = renderer_pix;
#line 211 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_cell_layout_add_attribute (G_TYPE_CHECK_INSTANCE_CAST (_tmp45_, GTK_TYPE_CELL_LAYOUT, GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp46_, gtk_cell_renderer_get_type (), GtkCellRenderer), "pixbuf", 0);
#line 213 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp47_ = (GtkCellRendererText*) gtk_cell_renderer_text_new ();
#line 213 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_object_ref_sink (_tmp47_);
#line 213 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	renderer_text = _tmp47_;
#line 214 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp48_ = self->priv->service_selector_box;
#line 214 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp49_ = renderer_text;
#line 214 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_cell_layout_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp48_, GTK_TYPE_CELL_LAYOUT, GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp49_, gtk_cell_renderer_get_type (), GtkCellRenderer), TRUE);
#line 215 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp50_ = self->priv->service_selector_box;
#line 215 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp51_ = renderer_text;
#line 215 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_cell_layout_add_attribute (G_TYPE_CHECK_INSTANCE_CAST (_tmp50_, GTK_TYPE_CELL_LAYOUT, GtkCellLayout), G_TYPE_CHECK_INSTANCE_CAST (_tmp51_, gtk_cell_renderer_get_type (), GtkCellRenderer), "text", 1);
#line 217 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp52_ = self->priv->service_selector_box;
#line 217 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_combo_box_set_active (_tmp52_, 0);
#line 220 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp53_ = config_facade_get_instance ();
#line 220 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp54_ = _tmp53_;
#line 220 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp55_ = configuration_facade_get_last_used_service (G_TYPE_CHECK_INSTANCE_CAST (_tmp54_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade));
#line 220 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp56_ = _tmp55_;
#line 220 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (_tmp54_);
#line 220 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	last_used_service = _tmp56_;
#line 222 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp57_ = has_photos;
#line 222 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp58_ = has_videos;
#line 222 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp60_ = publishing_ui_publishing_dialog_load_services (_tmp57_, _tmp58_, &_tmp59_);
#line 222 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	loaded_services = _tmp60_;
#line 222 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	loaded_services_length1 = _tmp59_;
#line 222 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_loaded_services_size_ = loaded_services_length1;
#line 226 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp61_ = loaded_services;
#line 226 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp61__length1 = loaded_services_length1;
#line 1737 "PublishingUI.c"
	{
		SpitPublishingService** service_collection = NULL;
		gint service_collection_length1 = 0;
		gint _service_collection_size_ = 0;
		gint service_it = 0;
#line 226 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		service_collection = _tmp61_;
#line 226 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		service_collection_length1 = _tmp61__length1;
#line 226 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		for (service_it = 0; service_it < _tmp61__length1; service_it = service_it + 1) {
#line 1749 "PublishingUI.c"
			SpitPublishingService* _tmp62_;
			SpitPublishingService* service = NULL;
#line 226 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp62_ = _g_object_ref0 (service_collection[service_it]);
#line 226 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			service = _tmp62_;
#line 1756 "PublishingUI.c"
			{
				GtkListStore* _tmp63_;
				GtkTreeIter _tmp64_ = {0};
				gchar* curr_service_id = NULL;
				SpitPublishingService* _tmp65_;
				const gchar* _tmp66_;
				gchar* _tmp67_;
				SpitPublishingService* _tmp68_;
				gboolean _tmp69_ = FALSE;
				SpitPluggableInfo _tmp70_;
				GdkPixbuf** _tmp71_;
				gint _tmp71__length1;
				const gchar* _tmp89_;
#line 227 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_tmp63_ = self->priv->service_selector_box_model;
#line 227 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				gtk_list_store_append (_tmp63_, &_tmp64_);
#line 227 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				iter = _tmp64_;
#line 229 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_tmp65_ = service;
#line 229 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_tmp66_ = spit_pluggable_get_id (G_TYPE_CHECK_INSTANCE_CAST (_tmp65_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 229 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_tmp67_ = g_strdup (_tmp66_);
#line 229 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				curr_service_id = _tmp67_;
#line 231 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_tmp68_ = service;
#line 231 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				spit_pluggable_get_info (G_TYPE_CHECK_INSTANCE_CAST (_tmp68_, SPIT_TYPE_PLUGGABLE, SpitPluggable), &self->priv->info);
#line 233 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_tmp70_ = self->priv->info;
#line 233 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_tmp71_ = _tmp70_.icons;
#line 233 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_tmp71__length1 = _tmp70_.icons_length1;
#line 233 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				if (NULL != _tmp71_) {
#line 1796 "PublishingUI.c"
					SpitPluggableInfo _tmp72_;
					GdkPixbuf** _tmp73_;
					gint _tmp73__length1;
#line 233 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp72_ = self->priv->info;
#line 233 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp73_ = _tmp72_.icons;
#line 233 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp73__length1 = _tmp72_.icons_length1;
#line 233 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp69_ = 0 < _tmp73__length1;
#line 1808 "PublishingUI.c"
				} else {
#line 233 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp69_ = FALSE;
#line 1812 "PublishingUI.c"
				}
#line 233 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				if (_tmp69_) {
#line 1816 "PublishingUI.c"
					GtkListStore* _tmp74_;
					GtkTreeIter _tmp75_;
					SpitPluggableInfo _tmp76_;
					GdkPixbuf** _tmp77_;
					gint _tmp77__length1;
					GdkPixbuf* _tmp78_;
					SpitPublishingService* _tmp79_;
					const gchar* _tmp80_;
					GdkPixbuf* _tmp81_;
					GdkPixbuf* _tmp82_;
#line 235 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp74_ = self->priv->service_selector_box_model;
#line 235 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp75_ = iter;
#line 235 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp76_ = self->priv->info;
#line 235 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp77_ = _tmp76_.icons;
#line 235 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp77__length1 = _tmp76_.icons_length1;
#line 235 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp78_ = _tmp77_[0];
#line 235 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp79_ = service;
#line 235 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp80_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp79_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 235 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					gtk_list_store_set (_tmp74_, &_tmp75_, 0, _tmp78_, 1, _tmp80_, -1);
#line 239 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp81_ = resources_get_icon (RESOURCES_ICON_GENERIC_PLUGIN, RESOURCES_DEFAULT_ICON_SCALE);
#line 239 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_g_object_unref0 (self->priv->info.icons[0]);
#line 239 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					self->priv->info.icons[0] = _tmp81_;
#line 239 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp82_ = self->priv->info.icons[0];
#line 1853 "PublishingUI.c"
				} else {
					GtkListStore* _tmp83_;
					GtkTreeIter _tmp84_;
					GdkPixbuf* _tmp85_;
					GdkPixbuf* _tmp86_;
					SpitPublishingService* _tmp87_;
					const gchar* _tmp88_;
#line 242 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp83_ = self->priv->service_selector_box_model;
#line 242 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp84_ = iter;
#line 242 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp85_ = resources_get_icon (RESOURCES_ICON_GENERIC_PLUGIN, RESOURCES_DEFAULT_ICON_SCALE);
#line 242 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp86_ = _tmp85_;
#line 242 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp87_ = service;
#line 242 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp88_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp87_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 242 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					gtk_list_store_set (_tmp83_, &_tmp84_, 0, _tmp86_, 1, _tmp88_, -1);
#line 242 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_g_object_unref0 (_tmp86_);
#line 1877 "PublishingUI.c"
				}
#line 246 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_tmp89_ = last_used_service;
#line 246 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				if (_tmp89_ == NULL) {
#line 1883 "PublishingUI.c"
					GtkComboBox* _tmp90_;
					GtkTreeIter _tmp91_;
					SpitPublishingService* _tmp92_;
					const gchar* _tmp93_;
					gchar* _tmp94_;
#line 247 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp90_ = self->priv->service_selector_box;
#line 247 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp91_ = iter;
#line 247 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					gtk_combo_box_set_active_iter (_tmp90_, &_tmp91_);
#line 248 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp92_ = service;
#line 248 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp93_ = spit_pluggable_get_id (G_TYPE_CHECK_INSTANCE_CAST (_tmp92_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 248 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp94_ = g_strdup (_tmp93_);
#line 248 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_g_free0 (last_used_service);
#line 248 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					last_used_service = _tmp94_;
#line 1905 "PublishingUI.c"
				} else {
					const gchar* _tmp95_;
					const gchar* _tmp96_;
#line 249 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp95_ = last_used_service;
#line 249 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp96_ = curr_service_id;
#line 249 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					if (g_strcmp0 (_tmp95_, _tmp96_) == 0) {
#line 1915 "PublishingUI.c"
						GtkComboBox* _tmp97_;
						GtkTreeIter _tmp98_;
#line 250 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
						_tmp97_ = self->priv->service_selector_box;
#line 250 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
						_tmp98_ = iter;
#line 250 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
						gtk_combo_box_set_active_iter (_tmp97_, &_tmp98_);
#line 1924 "PublishingUI.c"
					}
				}
#line 226 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_g_free0 (curr_service_id);
#line 226 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_g_object_unref0 (service);
#line 1931 "PublishingUI.c"
			}
		}
	}
#line 254 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp99_ = self->priv->service_selector_box;
#line 254 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_signal_connect_object (_tmp99_, "changed", (GCallback) _publishing_ui_publishing_dialog_on_service_changed_gtk_combo_box_changed, self, 0);
#line 256 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp100_ = use_header;
#line 256 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if (!_tmp100_) {
#line 1943 "PublishingUI.c"
		GtkLabel* service_selector_box_label = NULL;
		const gchar* _tmp101_;
		GtkLabel* _tmp102_;
		GtkLabel* _tmp103_;
		GtkComboBox* _tmp104_;
		GtkLabel* _tmp105_;
		GtkLabel* _tmp106_;
		GtkComboBox* _tmp107_;
		GtkComboBox* _tmp108_;
		GtkComboBox* _tmp109_;
		GtkComboBox* _tmp110_;
		GtkBox* service_selector_layouter = NULL;
		GtkBox* _tmp111_;
		GtkBox* _tmp112_;
		GtkBox* _tmp113_;
		GtkBox* _tmp114_;
		GtkLabel* _tmp115_;
		GtkBox* _tmp116_;
		GtkComboBox* _tmp117_;
		GtkBox* service_area_layouter = NULL;
		GtkBox* _tmp118_;
		GtkBox* _tmp119_;
		GtkBox* _tmp120_;
		GtkBox* _tmp121_;
		GtkSeparator* _tmp122_;
		GtkSeparator* _tmp123_;
		GtkBox* _tmp124_;
		GtkBox* _tmp125_;
		GtkBox* _tmp126_;
		GtkBox* _tmp127_;
		GtkBox* _tmp128_;
		GtkBox* _tmp129_;
#line 258 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp101_ = label;
#line 258 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp102_ = (GtkLabel*) gtk_label_new_with_mnemonic (_tmp101_);
#line 258 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		g_object_ref_sink (_tmp102_);
#line 258 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		service_selector_box_label = _tmp102_;
#line 259 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp103_ = service_selector_box_label;
#line 259 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp104_ = self->priv->service_selector_box;
#line 259 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_label_set_mnemonic_widget (_tmp103_, G_TYPE_CHECK_INSTANCE_CAST (_tmp104_, gtk_widget_get_type (), GtkWidget));
#line 260 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp105_ = service_selector_box_label;
#line 260 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_widget_set_halign (G_TYPE_CHECK_INSTANCE_CAST (_tmp105_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_START);
#line 261 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp106_ = service_selector_box_label;
#line 261 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_widget_set_valign (G_TYPE_CHECK_INSTANCE_CAST (_tmp106_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_CENTER);
#line 267 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp107_ = self->priv->service_selector_box;
#line 267 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_widget_set_halign (G_TYPE_CHECK_INSTANCE_CAST (_tmp107_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_END);
#line 268 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp108_ = self->priv->service_selector_box;
#line 268 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_widget_set_valign (G_TYPE_CHECK_INSTANCE_CAST (_tmp108_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_CENTER);
#line 269 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp109_ = self->priv->service_selector_box;
#line 269 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_widget_set_hexpand (G_TYPE_CHECK_INSTANCE_CAST (_tmp109_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 270 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp110_ = self->priv->service_selector_box;
#line 270 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_widget_set_vexpand (G_TYPE_CHECK_INSTANCE_CAST (_tmp110_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 272 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp111_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
#line 272 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		g_object_ref_sink (_tmp111_);
#line 272 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		service_selector_layouter = _tmp111_;
#line 273 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp112_ = service_selector_layouter;
#line 273 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_container_set_border_width (G_TYPE_CHECK_INSTANCE_CAST (_tmp112_, gtk_container_get_type (), GtkContainer), (guint) 12);
#line 274 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp113_ = service_selector_layouter;
#line 274 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_widget_set_hexpand (G_TYPE_CHECK_INSTANCE_CAST (_tmp113_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 275 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp114_ = service_selector_layouter;
#line 275 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp115_ = service_selector_box_label;
#line 275 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp114_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp115_, gtk_widget_get_type (), GtkWidget));
#line 276 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp116_ = service_selector_layouter;
#line 276 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp117_ = self->priv->service_selector_box;
#line 276 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_box_pack_start (_tmp116_, G_TYPE_CHECK_INSTANCE_CAST (_tmp117_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 280 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp118_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 280 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		g_object_ref_sink (_tmp118_);
#line 280 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		service_area_layouter = _tmp118_;
#line 281 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp119_ = service_area_layouter;
#line 281 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp120_ = service_selector_layouter;
#line 281 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp119_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp120_, gtk_widget_get_type (), GtkWidget));
#line 282 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp121_ = service_area_layouter;
#line 282 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp122_ = (GtkSeparator*) gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
#line 282 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		g_object_ref_sink (_tmp122_);
#line 282 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp123_ = _tmp122_;
#line 282 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_container_add (G_TYPE_CHECK_INSTANCE_CAST (_tmp121_, gtk_container_get_type (), GtkContainer), G_TYPE_CHECK_INSTANCE_CAST (_tmp123_, gtk_widget_get_type (), GtkWidget));
#line 282 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_g_object_unref0 (_tmp123_);
#line 283 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp124_ = service_area_layouter;
#line 283 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_widget_set_halign (G_TYPE_CHECK_INSTANCE_CAST (_tmp124_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_FILL);
#line 284 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp125_ = service_area_layouter;
#line 284 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_widget_set_valign (G_TYPE_CHECK_INSTANCE_CAST (_tmp125_, gtk_widget_get_type (), GtkWidget), GTK_ALIGN_START);
#line 285 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp126_ = service_area_layouter;
#line 285 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_widget_set_hexpand (G_TYPE_CHECK_INSTANCE_CAST (_tmp126_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 286 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp127_ = service_area_layouter;
#line 286 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_widget_set_vexpand (G_TYPE_CHECK_INSTANCE_CAST (_tmp127_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 288 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp128_ = (GtkBox*) gtk_dialog_get_content_area (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 288 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp129_ = service_area_layouter;
#line 288 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_box_pack_start (_tmp128_, G_TYPE_CHECK_INSTANCE_CAST (_tmp129_, gtk_widget_get_type (), GtkWidget), FALSE, FALSE, (guint) 0);
#line 256 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_g_object_unref0 (service_area_layouter);
#line 256 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_g_object_unref0 (service_selector_layouter);
#line 256 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_g_object_unref0 (service_selector_box_label);
#line 2092 "PublishingUI.c"
	}
#line 291 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp130_ = (GtkBox*) gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
#line 291 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_object_ref_sink (_tmp130_);
#line 291 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->central_area_layouter);
#line 291 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv->central_area_layouter = _tmp130_;
#line 293 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp131_ = (GtkBox*) gtk_dialog_get_content_area (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 293 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp132_ = self->priv->central_area_layouter;
#line 293 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_box_pack_start (_tmp131_, G_TYPE_CHECK_INSTANCE_CAST (_tmp132_, gtk_widget_get_type (), GtkWidget), TRUE, TRUE, (guint) 0);
#line 295 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp133_ = use_header;
#line 295 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if (_tmp133_) {
#line 2112 "PublishingUI.c"
		GtkButton* _tmp134_;
		GtkButton* _tmp135_;
		GtkWidget* _tmp136_;
		GtkButton* _tmp137_;
		GtkWidget* _tmp138_;
		GtkComboBox* _tmp139_;
#line 296 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp134_ = (GtkButton*) gtk_button_new_with_mnemonic ("_Cancel");
#line 296 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		g_object_ref_sink (_tmp134_);
#line 296 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_g_object_unref0 (self->priv->close_cancel_button);
#line 296 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		self->priv->close_cancel_button = _tmp134_;
#line 297 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp135_ = self->priv->close_cancel_button;
#line 297 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_widget_set_can_default (G_TYPE_CHECK_INSTANCE_CAST (_tmp135_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 299 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp136_ = gtk_dialog_get_header_bar (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 299 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp137_ = self->priv->close_cancel_button;
#line 299 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_header_bar_pack_start (G_TYPE_CHECK_INSTANCE_CAST (_tmp136_, gtk_header_bar_get_type (), GtkHeaderBar), G_TYPE_CHECK_INSTANCE_CAST (_tmp137_, gtk_widget_get_type (), GtkWidget));
#line 300 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp138_ = gtk_dialog_get_header_bar (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 300 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp139_ = self->priv->service_selector_box;
#line 300 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_header_bar_pack_end (G_TYPE_CHECK_INSTANCE_CAST (_tmp138_, gtk_header_bar_get_type (), GtkHeaderBar), G_TYPE_CHECK_INSTANCE_CAST (_tmp139_, gtk_widget_get_type (), GtkWidget));
#line 2143 "PublishingUI.c"
	} else {
		GtkWidget* _tmp140_;
		GtkButton* _tmp141_;
#line 303 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_dialog_add_button (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), _ ("_Cancel"), (gint) GTK_RESPONSE_CANCEL);
#line 304 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp140_ = gtk_dialog_get_widget_for_response (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog), (gint) GTK_RESPONSE_CANCEL);
#line 304 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp141_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp140_, gtk_button_get_type ()) ? ((GtkButton*) _tmp140_) : NULL);
#line 304 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_g_object_unref0 (self->priv->close_cancel_button);
#line 304 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		self->priv->close_cancel_button = _tmp141_;
#line 2157 "PublishingUI.c"
	}
#line 306 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp142_ = self->priv->close_cancel_button;
#line 306 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_signal_connect_object (_tmp142_, "clicked", (GCallback) _publishing_ui_publishing_dialog_on_close_cancel_clicked_gtk_button_clicked, self, 0);
#line 308 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	publishing_ui_publishing_dialog_set_standard_window_mode (self);
#line 310 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 161 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	loaded_services = (_vala_array_free (loaded_services, loaded_services_length1, (GDestroyNotify) g_object_unref), NULL);
#line 161 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_free0 (last_used_service);
#line 161 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (renderer_text);
#line 161 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (renderer_pix);
#line 161 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_free0 (label);
#line 161 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_free0 (title);
#line 161 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return self;
#line 2181 "PublishingUI.c"
}


PublishingUIPublishingDialog* publishing_ui_publishing_dialog_new (GeeCollection* to_publish) {
#line 161 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return publishing_ui_publishing_dialog_construct (PUBLISHING_UI_TYPE_PUBLISHING_DIALOG, to_publish);
#line 2188 "PublishingUI.c"
}


static void _vala_array_add56 (SpitPublishingService** * array, int* length, int* size, SpitPublishingService* value) {
#line 338 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if ((*length) == (*size)) {
#line 338 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 338 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		*array = g_renew (SpitPublishingService*, *array, (*size) + 1);
#line 2199 "PublishingUI.c"
	}
#line 338 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	(*array)[(*length)++] = value;
#line 338 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	(*array)[*length] = NULL;
#line 2205 "PublishingUI.c"
}


static gint __lambda15_ (void* a, void* b) {
	gint result = 0;
	void* _tmp0_;
	const gchar* _tmp1_;
	void* _tmp2_;
	const gchar* _tmp3_;
	gint _tmp4_;
#line 343 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = a;
#line 343 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp1_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (*((SpitPublishingService**) _tmp0_), SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 343 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp2_ = b;
#line 343 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp3_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (*((SpitPublishingService**) _tmp2_), SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 343 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp4_ = utf8_cs_compare (_tmp1_, _tmp3_);
#line 343 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	result = _tmp4_;
#line 343 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return result;
#line 2230 "PublishingUI.c"
}


static gint ___lambda15____compar_fn_t (void* key1, void* key2) {
	gint result;
	result = __lambda15_ (key1, key2);
#line 342 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return result;
#line 2239 "PublishingUI.c"
}


static SpitPublishingService** publishing_ui_publishing_dialog_load_all_services (int* result_length1) {
	SpitPublishingService** result = NULL;
	SpitPublishingService** loaded_services = NULL;
	SpitPublishingService** _tmp0_;
	gint loaded_services_length1;
	gint _loaded_services_size_;
	GeeCollection* pluggables = NULL;
	GeeCollection* _tmp1_;
	GeeCollection* _tmp2_;
	gint _tmp3_;
	gint _tmp4_;
	SpitPublishingService** _tmp25_;
	gint _tmp25__length1;
	SpitPublishingService** _tmp26_;
	gint _tmp26__length1;
	SpitPublishingService** _tmp27_;
	gint _tmp27__length1;
#line 314 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = g_new0 (SpitPublishingService*, 0 + 1);
#line 314 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	loaded_services = _tmp0_;
#line 314 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	loaded_services_length1 = 0;
#line 314 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_loaded_services_size_ = loaded_services_length1;
#line 317 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp1_ = plugins_get_pluggables_for_type (SPIT_PUBLISHING_TYPE_SERVICE, NULL, NULL, NULL, FALSE);
#line 317 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	pluggables = _tmp1_;
#line 320 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp2_ = pluggables;
#line 320 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp3_ = gee_collection_get_size (_tmp2_);
#line 320 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp4_ = _tmp3_;
#line 320 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_debug ("PublishingUI.vala:320: PublisingDialog: discovered %d pluggable publis" \
"hing services.", _tmp4_);
#line 2280 "PublishingUI.c"
	{
		GeeIterator* _pluggable_it = NULL;
		GeeCollection* _tmp5_;
		GeeIterator* _tmp6_;
#line 322 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp5_ = pluggables;
#line 322 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp6_ = gee_iterable_iterator (G_TYPE_CHECK_INSTANCE_CAST (_tmp5_, GEE_TYPE_ITERABLE, GeeIterable));
#line 322 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_pluggable_it = _tmp6_;
#line 322 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		while (TRUE) {
#line 2293 "PublishingUI.c"
			GeeIterator* _tmp7_;
			gboolean _tmp8_;
			SpitPluggable* pluggable = NULL;
			GeeIterator* _tmp9_;
			gpointer _tmp10_;
			gint pluggable_interface = 0;
			SpitPluggable* _tmp11_;
			gint _tmp12_;
			gint _tmp13_;
			SpitPublishingService* service = NULL;
			SpitPluggable* _tmp18_;
			SpitPublishingService* _tmp19_;
			SpitPublishingService* _tmp20_;
			const gchar* _tmp21_;
			SpitPublishingService** _tmp22_;
			gint _tmp22__length1;
			SpitPublishingService* _tmp23_;
			SpitPublishingService* _tmp24_;
#line 322 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp7_ = _pluggable_it;
#line 322 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp8_ = gee_iterator_next (_tmp7_);
#line 322 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			if (!_tmp8_) {
#line 322 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				break;
#line 2320 "PublishingUI.c"
			}
#line 322 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp9_ = _pluggable_it;
#line 322 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp10_ = gee_iterator_get (_tmp9_);
#line 322 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			pluggable = (SpitPluggable*) _tmp10_;
#line 323 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp11_ = pluggable;
#line 323 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp12_ = spit_pluggable_get_pluggable_interface (_tmp11_, SPIT_PUBLISHING_CURRENT_INTERFACE, SPIT_PUBLISHING_CURRENT_INTERFACE);
#line 323 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			pluggable_interface = _tmp12_;
#line 325 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp13_ = pluggable_interface;
#line 325 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			if (_tmp13_ != SPIT_PUBLISHING_CURRENT_INTERFACE) {
#line 2338 "PublishingUI.c"
				SpitPluggable* _tmp14_;
				gchar* _tmp15_;
				gchar* _tmp16_;
				gint _tmp17_;
#line 326 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_tmp14_ = pluggable;
#line 326 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_tmp15_ = plugins_get_pluggable_module_id (_tmp14_);
#line 326 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_tmp16_ = _tmp15_;
#line 326 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_tmp17_ = pluggable_interface;
#line 326 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				g_warning ("PublishingUI.vala:326: Unable to load publisher %s: reported interface" \
" %d.", _tmp16_, _tmp17_);
#line 326 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_g_free0 (_tmp16_);
#line 329 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_g_object_unref0 (pluggable);
#line 329 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				continue;
#line 2359 "PublishingUI.c"
			}
#line 332 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp18_ = pluggable;
#line 332 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp19_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, SPIT_PUBLISHING_TYPE_SERVICE, SpitPublishingService));
#line 332 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			service = _tmp19_;
#line 335 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp20_ = service;
#line 335 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp21_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp20_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 335 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			g_debug ("PublishingUI.vala:335: PublishingDialog: discovered pluggable publishi" \
"ng service '%s'.", _tmp21_);
#line 338 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp22_ = loaded_services;
#line 338 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp22__length1 = loaded_services_length1;
#line 338 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp23_ = service;
#line 338 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp24_ = _g_object_ref0 (_tmp23_);
#line 338 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_vala_array_add56 (&loaded_services, &loaded_services_length1, &_loaded_services_size_, _tmp24_);
#line 322 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_g_object_unref0 (service);
#line 322 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_g_object_unref0 (pluggable);
#line 2387 "PublishingUI.c"
		}
#line 322 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_g_object_unref0 (_pluggable_it);
#line 2391 "PublishingUI.c"
	}
#line 342 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp25_ = loaded_services;
#line 342 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp25__length1 = loaded_services_length1;
#line 342 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp26_ = loaded_services;
#line 342 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp26__length1 = loaded_services_length1;
#line 342 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	qsort (_tmp25_, (gsize) _tmp26__length1, (gsize) sizeof (SpitPublishingService*), ___lambda15____compar_fn_t);
#line 347 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp27_ = loaded_services;
#line 347 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp27__length1 = loaded_services_length1;
#line 347 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if (result_length1) {
#line 347 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		*result_length1 = _tmp27__length1;
#line 2411 "PublishingUI.c"
	}
#line 347 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	result = _tmp27_;
#line 347 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (pluggables);
#line 347 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return result;
#line 2419 "PublishingUI.c"
}


static void _vala_array_add57 (SpitPublishingService** * array, int* length, int* size, SpitPublishingService* value) {
#line 360 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if ((*length) == (*size)) {
#line 360 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 360 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		*array = g_renew (SpitPublishingService*, *array, (*size) + 1);
#line 2430 "PublishingUI.c"
	}
#line 360 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	(*array)[(*length)++] = value;
#line 360 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	(*array)[*length] = NULL;
#line 2436 "PublishingUI.c"
}


static void _vala_array_add58 (SpitPublishingService** * array, int* length, int* size, SpitPublishingService* value) {
#line 363 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if ((*length) == (*size)) {
#line 363 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 363 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		*array = g_renew (SpitPublishingService*, *array, (*size) + 1);
#line 2447 "PublishingUI.c"
	}
#line 363 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	(*array)[(*length)++] = value;
#line 363 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	(*array)[*length] = NULL;
#line 2453 "PublishingUI.c"
}


static void _vala_array_add59 (SpitPublishingService** * array, int* length, int* size, SpitPublishingService* value) {
#line 367 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if ((*length) == (*size)) {
#line 367 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 367 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		*array = g_renew (SpitPublishingService*, *array, (*size) + 1);
#line 2464 "PublishingUI.c"
	}
#line 367 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	(*array)[(*length)++] = value;
#line 367 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	(*array)[*length] = NULL;
#line 2470 "PublishingUI.c"
}


static SpitPublishingService** publishing_ui_publishing_dialog_load_services (gboolean has_photos, gboolean has_videos, int* result_length1) {
	SpitPublishingService** result = NULL;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_;
	SpitPublishingService** filtered_services = NULL;
	SpitPublishingService** _tmp3_;
	gint filtered_services_length1;
	gint _filtered_services_size_;
	SpitPublishingService** all_services = NULL;
	gint _tmp4_;
	SpitPublishingService** _tmp5_;
	gint all_services_length1;
	gint _all_services_size_;
	SpitPublishingService** _tmp6_;
	gint _tmp6__length1;
	SpitPublishingService** _tmp32_;
	gint _tmp32__length1;
#line 351 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp1_ = has_photos;
#line 351 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if (_tmp1_) {
#line 351 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp0_ = TRUE;
#line 2497 "PublishingUI.c"
	} else {
		gboolean _tmp2_;
#line 351 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp2_ = has_videos;
#line 351 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp0_ = _tmp2_;
#line 2504 "PublishingUI.c"
	}
#line 351 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_vala_assert (_tmp0_, "has_photos || has_videos");
#line 353 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp3_ = g_new0 (SpitPublishingService*, 0 + 1);
#line 353 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	filtered_services = _tmp3_;
#line 353 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	filtered_services_length1 = 0;
#line 353 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_filtered_services_size_ = filtered_services_length1;
#line 354 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp5_ = publishing_ui_publishing_dialog_load_all_services (&_tmp4_);
#line 354 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	all_services = _tmp5_;
#line 354 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	all_services_length1 = _tmp4_;
#line 354 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_all_services_size_ = all_services_length1;
#line 356 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp6_ = all_services;
#line 356 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp6__length1 = all_services_length1;
#line 2528 "PublishingUI.c"
	{
		SpitPublishingService** service_collection = NULL;
		gint service_collection_length1 = 0;
		gint _service_collection_size_ = 0;
		gint service_it = 0;
#line 356 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		service_collection = _tmp6_;
#line 356 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		service_collection_length1 = _tmp6__length1;
#line 356 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		for (service_it = 0; service_it < _tmp6__length1; service_it = service_it + 1) {
#line 2540 "PublishingUI.c"
			SpitPublishingService* _tmp7_;
			SpitPublishingService* service = NULL;
#line 356 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp7_ = _g_object_ref0 (service_collection[service_it]);
#line 356 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			service = _tmp7_;
#line 2547 "PublishingUI.c"
			{
				gboolean _tmp8_ = FALSE;
				gboolean _tmp9_;
#line 358 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_tmp9_ = has_photos;
#line 358 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				if (_tmp9_) {
#line 2555 "PublishingUI.c"
					gboolean _tmp10_;
#line 358 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp10_ = has_videos;
#line 358 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp8_ = !_tmp10_;
#line 2561 "PublishingUI.c"
				} else {
#line 358 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp8_ = FALSE;
#line 2565 "PublishingUI.c"
				}
#line 358 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				if (_tmp8_) {
#line 2569 "PublishingUI.c"
					SpitPublishingService* _tmp11_;
					SpitPublishingPublisherMediaType _tmp12_;
#line 359 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp11_ = service;
#line 359 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp12_ = spit_publishing_service_get_supported_media (_tmp11_);
#line 359 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					if ((_tmp12_ & SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO) != 0) {
#line 2578 "PublishingUI.c"
						SpitPublishingService** _tmp13_;
						gint _tmp13__length1;
						SpitPublishingService* _tmp14_;
						SpitPublishingService* _tmp15_;
#line 360 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
						_tmp13_ = filtered_services;
#line 360 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
						_tmp13__length1 = filtered_services_length1;
#line 360 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
						_tmp14_ = service;
#line 360 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
						_tmp15_ = _g_object_ref0 (_tmp14_);
#line 360 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
						_vala_array_add57 (&filtered_services, &filtered_services_length1, &_filtered_services_size_, _tmp15_);
#line 2593 "PublishingUI.c"
					}
				} else {
					gboolean _tmp16_ = FALSE;
					gboolean _tmp17_;
#line 361 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp17_ = has_photos;
#line 361 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					if (!_tmp17_) {
#line 2602 "PublishingUI.c"
						gboolean _tmp18_;
#line 361 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
						_tmp18_ = has_videos;
#line 361 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
						_tmp16_ = _tmp18_;
#line 2608 "PublishingUI.c"
					} else {
#line 361 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
						_tmp16_ = FALSE;
#line 2612 "PublishingUI.c"
					}
#line 361 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					if (_tmp16_) {
#line 2616 "PublishingUI.c"
						SpitPublishingService* _tmp19_;
						SpitPublishingPublisherMediaType _tmp20_;
#line 362 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
						_tmp19_ = service;
#line 362 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
						_tmp20_ = spit_publishing_service_get_supported_media (_tmp19_);
#line 362 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
						if ((_tmp20_ & SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) != 0) {
#line 2625 "PublishingUI.c"
							SpitPublishingService** _tmp21_;
							gint _tmp21__length1;
							SpitPublishingService* _tmp22_;
							SpitPublishingService* _tmp23_;
#line 363 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
							_tmp21_ = filtered_services;
#line 363 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
							_tmp21__length1 = filtered_services_length1;
#line 363 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
							_tmp22_ = service;
#line 363 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
							_tmp23_ = _g_object_ref0 (_tmp22_);
#line 363 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
							_vala_array_add58 (&filtered_services, &filtered_services_length1, &_filtered_services_size_, _tmp23_);
#line 2640 "PublishingUI.c"
						}
					} else {
						gboolean _tmp24_ = FALSE;
						SpitPublishingService* _tmp25_;
						SpitPublishingPublisherMediaType _tmp26_;
#line 365 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
						_tmp25_ = service;
#line 365 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
						_tmp26_ = spit_publishing_service_get_supported_media (_tmp25_);
#line 365 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
						if ((_tmp26_ & SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_PHOTO) != 0) {
#line 2652 "PublishingUI.c"
							SpitPublishingService* _tmp27_;
							SpitPublishingPublisherMediaType _tmp28_;
#line 366 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
							_tmp27_ = service;
#line 366 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
							_tmp28_ = spit_publishing_service_get_supported_media (_tmp27_);
#line 366 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
							_tmp24_ = (_tmp28_ & SPIT_PUBLISHING_PUBLISHER_MEDIA_TYPE_VIDEO) != 0;
#line 2661 "PublishingUI.c"
						} else {
#line 365 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
							_tmp24_ = FALSE;
#line 2665 "PublishingUI.c"
						}
#line 365 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
						if (_tmp24_) {
#line 2669 "PublishingUI.c"
							SpitPublishingService** _tmp29_;
							gint _tmp29__length1;
							SpitPublishingService* _tmp30_;
							SpitPublishingService* _tmp31_;
#line 367 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
							_tmp29_ = filtered_services;
#line 367 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
							_tmp29__length1 = filtered_services_length1;
#line 367 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
							_tmp30_ = service;
#line 367 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
							_tmp31_ = _g_object_ref0 (_tmp30_);
#line 367 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
							_vala_array_add59 (&filtered_services, &filtered_services_length1, &_filtered_services_size_, _tmp31_);
#line 2684 "PublishingUI.c"
						}
					}
				}
#line 356 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_g_object_unref0 (service);
#line 2690 "PublishingUI.c"
			}
		}
	}
#line 371 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp32_ = filtered_services;
#line 371 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp32__length1 = filtered_services_length1;
#line 371 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if (result_length1) {
#line 371 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		*result_length1 = _tmp32__length1;
#line 2702 "PublishingUI.c"
	}
#line 371 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	result = _tmp32_;
#line 371 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	all_services = (_vala_array_free (all_services, all_services_length1, (GDestroyNotify) g_object_unref), NULL);
#line 371 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return result;
#line 2710 "PublishingUI.c"
}


void publishing_ui_publishing_dialog_go (GeeCollection* to_publish) {
	PublishingUIPublishingDialog* _tmp0_;
	GTimer* _tmp1_;
	GeeArrayList* photos = NULL;
	GeeArrayList* _tmp10_;
	GeeArrayList* videos = NULL;
	GeeArrayList* _tmp11_;
	GeeCollection* _tmp12_;
	GeeArrayList* _tmp13_;
	GeeArrayList* _tmp14_;
	SpitPublishingService** avail_services = NULL;
	GeeArrayList* _tmp15_;
	gint _tmp16_;
	gint _tmp17_;
	GeeArrayList* _tmp18_;
	gint _tmp19_;
	gint _tmp20_;
	gint _tmp21_;
	SpitPublishingService** _tmp22_;
	gint avail_services_length1;
	gint _avail_services_size_;
	SpitPublishingService** _tmp23_;
	gint _tmp23__length1;
	GeeCollection* _tmp26_;
	PublishingUIPublishingDialog* _tmp27_;
	PublishingUIPublishingDialog* _tmp28_;
	GTimer* _tmp29_;
#line 385 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_if_fail (GEE_IS_COLLECTION (to_publish));
#line 386 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = publishing_ui_publishing_dialog_active_instance;
#line 386 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if (_tmp0_ != NULL) {
#line 387 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		return;
#line 2749 "PublishingUI.c"
	}
#line 389 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp1_ = publishing_ui_publishing_dialog_since_last_start;
#line 389 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if (_tmp1_ == NULL) {
#line 2755 "PublishingUI.c"
		GTimer* _tmp2_;
		GTimer* _tmp3_;
		GTimer* _tmp4_;
#line 392 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp2_ = g_timer_new ();
#line 392 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_g_timer_destroy0 (publishing_ui_publishing_dialog_since_last_start);
#line 392 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		publishing_ui_publishing_dialog_since_last_start = _tmp2_;
#line 393 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp3_ = publishing_ui_publishing_dialog_since_last_start;
#line 393 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		g_timer_stop (_tmp3_);
#line 394 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp4_ = publishing_ui_publishing_dialog_since_last_start;
#line 394 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		g_timer_reset (_tmp4_);
#line 395 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		publishing_ui_publishing_dialog_elapsed_is_valid = FALSE;
#line 2775 "PublishingUI.c"
	} else {
		gdouble elapsed = 0.0;
		GTimer* _tmp5_;
		gdouble _tmp6_;
		gboolean _tmp7_ = FALSE;
		gdouble _tmp8_;
#line 397 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp5_ = publishing_ui_publishing_dialog_since_last_start;
#line 397 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp6_ = g_timer_elapsed (_tmp5_, NULL);
#line 397 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		elapsed = _tmp6_;
#line 398 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp8_ = elapsed;
#line 398 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		if (_tmp8_ < 0.05) {
#line 2792 "PublishingUI.c"
			gboolean _tmp9_;
#line 398 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp9_ = publishing_ui_publishing_dialog_elapsed_is_valid;
#line 398 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp7_ = _tmp9_;
#line 2798 "PublishingUI.c"
		} else {
#line 398 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp7_ = FALSE;
#line 2802 "PublishingUI.c"
		}
#line 398 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		if (_tmp7_) {
#line 399 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			return;
#line 2808 "PublishingUI.c"
		}
	}
#line 402 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp10_ = gee_array_list_new (TYPE_LIBRARY_PHOTO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 402 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	photos = _tmp10_;
#line 403 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp11_ = gee_array_list_new (TYPE_VIDEO, (GBoxedCopyFunc) g_object_ref, (GDestroyNotify) g_object_unref, NULL, NULL, NULL);
#line 403 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	videos = _tmp11_;
#line 404 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp12_ = to_publish;
#line 404 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp13_ = photos;
#line 404 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp14_ = videos;
#line 404 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	media_source_collection_filter_media (_tmp12_, G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GEE_TYPE_COLLECTION, GeeCollection), G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, GEE_TYPE_COLLECTION, GeeCollection));
#line 406 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp15_ = photos;
#line 406 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp16_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp15_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 406 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp17_ = _tmp16_;
#line 406 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp18_ = videos;
#line 406 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp19_ = gee_abstract_collection_get_size (G_TYPE_CHECK_INSTANCE_CAST (_tmp18_, GEE_TYPE_ABSTRACT_COLLECTION, GeeAbstractCollection));
#line 406 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp20_ = _tmp19_;
#line 406 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp22_ = publishing_ui_publishing_dialog_load_services (_tmp17_ > 0, _tmp20_ > 0, &_tmp21_);
#line 406 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	avail_services = _tmp22_;
#line 406 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	avail_services_length1 = _tmp21_;
#line 406 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_avail_services_size_ = avail_services_length1;
#line 409 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp23_ = avail_services;
#line 409 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp23__length1 = avail_services_length1;
#line 409 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if (_tmp23__length1 == 0) {
#line 2853 "PublishingUI.c"
		gchar* _tmp24_;
		gchar* _tmp25_;
#line 412 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp24_ = g_strdup_printf (_ ("Shotwell cannot publish the selected items because you do not have a c" \
"ompatible publishing plugin enabled. To correct this, choose <b>Edit %" \
"s Preferences</b> and enable one or more of the publishing plugins on " \
"the <b>Plugins</b> tab."), "▸");
#line 412 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp25_ = _tmp24_;
#line 412 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		app_window_error_message_with_title (_ ("Unable to publish"), _tmp25_, NULL, FALSE);
#line 412 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_g_free0 (_tmp25_);
#line 416 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		avail_services = (_vala_array_free (avail_services, avail_services_length1, (GDestroyNotify) g_object_unref), NULL);
#line 416 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_g_object_unref0 (videos);
#line 416 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_g_object_unref0 (photos);
#line 416 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		return;
#line 2872 "PublishingUI.c"
	}
#line 422 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_debug ("PublishingUI.vala:422: PublishingDialog.go( )");
#line 424 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp26_ = to_publish;
#line 424 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp27_ = publishing_ui_publishing_dialog_new (_tmp26_);
#line 424 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_object_ref_sink (_tmp27_);
#line 424 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (publishing_ui_publishing_dialog_active_instance);
#line 424 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	publishing_ui_publishing_dialog_active_instance = _tmp27_;
#line 426 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp28_ = publishing_ui_publishing_dialog_active_instance;
#line 426 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	publishing_ui_publishing_dialog_run (_tmp28_);
#line 428 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (publishing_ui_publishing_dialog_active_instance);
#line 428 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	publishing_ui_publishing_dialog_active_instance = NULL;
#line 431 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp29_ = publishing_ui_publishing_dialog_since_last_start;
#line 431 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_timer_start (_tmp29_);
#line 432 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	publishing_ui_publishing_dialog_elapsed_is_valid = TRUE;
#line 385 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	avail_services = (_vala_array_free (avail_services, avail_services_length1, (GDestroyNotify) g_object_unref), NULL);
#line 385 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (videos);
#line 385 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (photos);
#line 2906 "PublishingUI.c"
}


static gboolean publishing_ui_publishing_dialog_on_window_close (PublishingUIPublishingDialog* self, GdkEventAny* evt) {
	gboolean result = FALSE;
	SpitPublishingConcretePublishingHost* _tmp0_;
#line 435 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_val_if_fail (PUBLISHING_UI_IS_PUBLISHING_DIALOG (self), FALSE);
#line 435 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_val_if_fail (evt != NULL, FALSE);
#line 436 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = self->priv->host;
#line 436 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	spit_publishing_plugin_host_stop_publishing (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_PUBLISHING_TYPE_PLUGIN_HOST, SpitPublishingPluginHost));
#line 437 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->host);
#line 437 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv->host = NULL;
#line 438 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 439 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 441 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	result = TRUE;
#line 441 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return result;
#line 2933 "PublishingUI.c"
}


static void publishing_ui_publishing_dialog_on_service_changed (PublishingUIPublishingDialog* self) {
	GtkTreeIter iter = {0};
	gboolean have_active_iter = FALSE;
	GtkComboBox* _tmp0_;
	GtkTreeIter _tmp1_ = {0};
	gboolean _tmp2_;
	gboolean _tmp3_;
	GValue service_name_val = {0};
	GtkListStore* _tmp7_;
	GtkTreeIter _tmp8_;
	GValue _tmp9_ = {0};
	gchar* service_name = NULL;
	GValue _tmp10_;
	gchar* _tmp11_;
	SpitPublishingService* selected_service = NULL;
	SpitPublishingService** services = NULL;
	gint _tmp12_;
	SpitPublishingService** _tmp13_;
	gint services_length1;
	gint _services_size_;
	SpitPublishingService** _tmp14_;
	gint _tmp14__length1;
	SpitPublishingService* _tmp21_;
	ConfigFacade* _tmp22_;
	ConfigFacade* _tmp23_;
	SpitPublishingService* _tmp24_;
	const gchar* _tmp25_;
	SpitPublishingService* _tmp26_;
	SpitPublishingPublishable** _tmp27_;
	gint _tmp27__length1;
	SpitPublishingConcretePublishingHost* _tmp28_;
	SpitPublishingConcretePublishingHost* _tmp29_;
#line 444 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_if_fail (PUBLISHING_UI_IS_PUBLISHING_DIALOG (self));
#line 446 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	have_active_iter = FALSE;
#line 447 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = self->priv->service_selector_box;
#line 447 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp2_ = gtk_combo_box_get_active_iter (_tmp0_, &_tmp1_);
#line 447 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	iter = _tmp1_;
#line 447 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	have_active_iter = _tmp2_;
#line 450 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp3_ = have_active_iter;
#line 450 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if (!_tmp3_) {
#line 2985 "PublishingUI.c"
		GtkComboBox* _tmp4_;
		GtkComboBox* _tmp5_;
		GtkTreeIter _tmp6_ = {0};
#line 452 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp4_ = self->priv->service_selector_box;
#line 452 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_combo_box_set_active (_tmp4_, 0);
#line 455 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp5_ = self->priv->service_selector_box;
#line 455 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_combo_box_get_active_iter (_tmp5_, &_tmp6_);
#line 455 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		iter = _tmp6_;
#line 2999 "PublishingUI.c"
	}
#line 459 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp7_ = self->priv->service_selector_box_model;
#line 459 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp8_ = iter;
#line 459 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_tree_model_get_value (G_TYPE_CHECK_INSTANCE_CAST (_tmp7_, GTK_TYPE_TREE_MODEL, GtkTreeModel), &_tmp8_, 1, &_tmp9_);
#line 459 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	G_IS_VALUE (&service_name_val) ? (g_value_unset (&service_name_val), NULL) : NULL;
#line 459 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	service_name_val = _tmp9_;
#line 461 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp10_ = service_name_val;
#line 461 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp11_ = g_strdup (g_value_get_string (&_tmp10_));
#line 461 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	service_name = _tmp11_;
#line 463 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	selected_service = NULL;
#line 464 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp13_ = publishing_ui_publishing_dialog_load_all_services (&_tmp12_);
#line 464 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	services = _tmp13_;
#line 464 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	services_length1 = _tmp12_;
#line 464 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_services_size_ = services_length1;
#line 465 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp14_ = services;
#line 465 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp14__length1 = services_length1;
#line 3031 "PublishingUI.c"
	{
		SpitPublishingService** service_collection = NULL;
		gint service_collection_length1 = 0;
		gint _service_collection_size_ = 0;
		gint service_it = 0;
#line 465 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		service_collection = _tmp14_;
#line 465 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		service_collection_length1 = _tmp14__length1;
#line 465 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		for (service_it = 0; service_it < _tmp14__length1; service_it = service_it + 1) {
#line 3043 "PublishingUI.c"
			SpitPublishingService* _tmp15_;
			SpitPublishingService* service = NULL;
#line 465 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			_tmp15_ = _g_object_ref0 (service_collection[service_it]);
#line 465 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			service = _tmp15_;
#line 3050 "PublishingUI.c"
			{
				SpitPublishingService* _tmp16_;
				const gchar* _tmp17_;
				const gchar* _tmp18_;
#line 466 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_tmp16_ = service;
#line 466 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_tmp17_ = spit_pluggable_get_pluggable_name (G_TYPE_CHECK_INSTANCE_CAST (_tmp16_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 466 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_tmp18_ = service_name;
#line 466 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				if (g_strcmp0 (_tmp17_, _tmp18_) == 0) {
#line 3063 "PublishingUI.c"
					SpitPublishingService* _tmp19_;
					SpitPublishingService* _tmp20_;
#line 467 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp19_ = service;
#line 467 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_tmp20_ = _g_object_ref0 (_tmp19_);
#line 467 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_g_object_unref0 (selected_service);
#line 467 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					selected_service = _tmp20_;
#line 468 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					_g_object_unref0 (service);
#line 468 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
					break;
#line 3078 "PublishingUI.c"
				}
#line 465 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
				_g_object_unref0 (service);
#line 3082 "PublishingUI.c"
			}
		}
	}
#line 471 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp21_ = selected_service;
#line 471 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_vala_assert (_tmp21_ != NULL, "selected_service != null");
#line 473 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp22_ = config_facade_get_instance ();
#line 473 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp23_ = _tmp22_;
#line 473 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp24_ = selected_service;
#line 473 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp25_ = spit_pluggable_get_id (G_TYPE_CHECK_INSTANCE_CAST (_tmp24_, SPIT_TYPE_PLUGGABLE, SpitPluggable));
#line 473 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	configuration_facade_set_last_used_service (G_TYPE_CHECK_INSTANCE_CAST (_tmp23_, TYPE_CONFIGURATION_FACADE, ConfigurationFacade), _tmp25_);
#line 473 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (_tmp23_);
#line 475 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp26_ = selected_service;
#line 475 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp27_ = self->priv->publishables;
#line 475 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp27__length1 = self->priv->publishables_length1;
#line 475 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp28_ = spit_publishing_concrete_publishing_host_new (_tmp26_, self, _tmp27_, _tmp27__length1);
#line 475 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->host);
#line 475 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv->host = _tmp28_;
#line 476 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp29_ = self->priv->host;
#line 476 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	spit_publishing_concrete_publishing_host_start_publishing (_tmp29_);
#line 444 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	services = (_vala_array_free (services, services_length1, (GDestroyNotify) g_object_unref), NULL);
#line 444 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (selected_service);
#line 444 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_free0 (service_name);
#line 444 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	G_IS_VALUE (&service_name_val) ? (g_value_unset (&service_name_val), NULL) : NULL;
#line 3126 "PublishingUI.c"
}


static void publishing_ui_publishing_dialog_on_close_cancel_clicked (PublishingUIPublishingDialog* self) {
	SpitPublishingConcretePublishingHost* _tmp0_;
#line 479 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_if_fail (PUBLISHING_UI_IS_PUBLISHING_DIALOG (self));
#line 480 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_debug ("PublishingUI.vala:480: PublishingDialog: on_close_cancel_clicked( ): i" \
"nvoked.");
#line 482 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = self->priv->host;
#line 482 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	spit_publishing_plugin_host_stop_publishing (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, SPIT_PUBLISHING_TYPE_PLUGIN_HOST, SpitPublishingPluginHost));
#line 483 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->host);
#line 483 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv->host = NULL;
#line 484 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_widget_hide (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 485 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_widget_destroy (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 3148 "PublishingUI.c"
}


static void publishing_ui_publishing_dialog_set_large_window_mode (PublishingUIPublishingDialog* self) {
	GtkBox* _tmp0_;
#line 488 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_if_fail (PUBLISHING_UI_IS_PUBLISHING_DIALOG (self));
#line 489 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), PUBLISHING_UI_PUBLISHING_DIALOG_LARGE_WINDOW_WIDTH, PUBLISHING_UI_PUBLISHING_DIALOG_LARGE_WINDOW_HEIGHT);
#line 490 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = self->priv->central_area_layouter;
#line 490 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), PUBLISHING_UI_PUBLISHING_DIALOG_LARGE_WINDOW_WIDTH - PUBLISHING_UI_PUBLISHING_DIALOG_BORDER_REGION_WIDTH, PUBLISHING_UI_PUBLISHING_DIALOG_LARGE_WINDOW_HEIGHT - PUBLISHING_UI_PUBLISHING_DIALOG_BORDER_REGION_HEIGHT);
#line 492 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 3164 "PublishingUI.c"
}


static void publishing_ui_publishing_dialog_set_colossal_window_mode (PublishingUIPublishingDialog* self) {
	GtkBox* _tmp0_;
#line 495 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_if_fail (PUBLISHING_UI_IS_PUBLISHING_DIALOG (self));
#line 496 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), PUBLISHING_UI_PUBLISHING_DIALOG_COLOSSAL_WINDOW_WIDTH, PUBLISHING_UI_PUBLISHING_DIALOG_COLOSSAL_WINDOW_HEIGHT);
#line 497 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = self->priv->central_area_layouter;
#line 497 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), PUBLISHING_UI_PUBLISHING_DIALOG_COLOSSAL_WINDOW_WIDTH - PUBLISHING_UI_PUBLISHING_DIALOG_BORDER_REGION_WIDTH, PUBLISHING_UI_PUBLISHING_DIALOG_COLOSSAL_WINDOW_HEIGHT - PUBLISHING_UI_PUBLISHING_DIALOG_BORDER_REGION_HEIGHT);
#line 499 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 3180 "PublishingUI.c"
}


static void publishing_ui_publishing_dialog_set_standard_window_mode (PublishingUIPublishingDialog* self) {
	GtkBox* _tmp0_;
#line 502 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_if_fail (PUBLISHING_UI_IS_PUBLISHING_DIALOG (self));
#line 503 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget), PUBLISHING_UI_PUBLISHING_DIALOG_STANDARD_WINDOW_WIDTH, PUBLISHING_UI_PUBLISHING_DIALOG_STANDARD_WINDOW_HEIGHT);
#line 504 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = self->priv->central_area_layouter;
#line 504 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_widget_set_size_request (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), PUBLISHING_UI_PUBLISHING_DIALOG_STANDARD_WINDOW_WIDTH - PUBLISHING_UI_PUBLISHING_DIALOG_BORDER_REGION_WIDTH, PUBLISHING_UI_PUBLISHING_DIALOG_STANDARD_WINDOW_HEIGHT - PUBLISHING_UI_PUBLISHING_DIALOG_BORDER_REGION_HEIGHT);
#line 506 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 3196 "PublishingUI.c"
}


static void publishing_ui_publishing_dialog_set_free_sizable_window_mode (PublishingUIPublishingDialog* self) {
#line 509 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_if_fail (PUBLISHING_UI_IS_PUBLISHING_DIALOG (self));
#line 510 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), TRUE);
#line 3205 "PublishingUI.c"
}


static void publishing_ui_publishing_dialog_clear_free_sizable_window_mode (PublishingUIPublishingDialog* self) {
#line 513 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_if_fail (PUBLISHING_UI_IS_PUBLISHING_DIALOG (self));
#line 514 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_window_set_resizable (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), FALSE);
#line 3214 "PublishingUI.c"
}


SpitPublishingDialogPane* publishing_ui_publishing_dialog_get_active_pane (PublishingUIPublishingDialog* self) {
	SpitPublishingDialogPane* result = NULL;
	SpitPublishingDialogPane* _tmp0_;
	SpitPublishingDialogPane* _tmp1_;
#line 517 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_val_if_fail (PUBLISHING_UI_IS_PUBLISHING_DIALOG (self), NULL);
#line 518 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = self->priv->active_pane;
#line 518 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 518 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	result = _tmp1_;
#line 518 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return result;
#line 3232 "PublishingUI.c"
}


void publishing_ui_publishing_dialog_set_close_button_mode (PublishingUIPublishingDialog* self) {
	GtkButton* _tmp0_;
	GtkButton* _tmp1_;
#line 521 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_if_fail (PUBLISHING_UI_IS_PUBLISHING_DIALOG (self));
#line 522 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = self->priv->close_cancel_button;
#line 522 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_button_set_label (_tmp0_, _ ("_Close"));
#line 523 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp1_ = self->priv->close_cancel_button;
#line 523 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_window_set_default (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_window_get_type (), GtkWindow), G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, gtk_widget_get_type (), GtkWidget));
#line 3249 "PublishingUI.c"
}


void publishing_ui_publishing_dialog_set_cancel_button_mode (PublishingUIPublishingDialog* self) {
	GtkButton* _tmp0_;
#line 526 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_if_fail (PUBLISHING_UI_IS_PUBLISHING_DIALOG (self));
#line 527 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = self->priv->close_cancel_button;
#line 527 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_button_set_label (_tmp0_, _ ("_Cancel"));
#line 3261 "PublishingUI.c"
}


void publishing_ui_publishing_dialog_lock_service (PublishingUIPublishingDialog* self) {
	GtkComboBox* _tmp0_;
#line 530 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_if_fail (PUBLISHING_UI_IS_PUBLISHING_DIALOG (self));
#line 531 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = self->priv->service_selector_box;
#line 531 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), FALSE);
#line 3273 "PublishingUI.c"
}


void publishing_ui_publishing_dialog_unlock_service (PublishingUIPublishingDialog* self) {
	GtkComboBox* _tmp0_;
#line 534 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_if_fail (PUBLISHING_UI_IS_PUBLISHING_DIALOG (self));
#line 535 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = self->priv->service_selector_box;
#line 535 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_widget_set_sensitive (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, gtk_widget_get_type (), GtkWidget), TRUE);
#line 3285 "PublishingUI.c"
}


void publishing_ui_publishing_dialog_install_pane (PublishingUIPublishingDialog* self, SpitPublishingDialogPane* pane) {
	SpitPublishingDialogPane* _tmp0_;
	GtkBox* _tmp6_;
	SpitPublishingDialogPane* _tmp7_;
	GtkWidget* _tmp8_;
	GtkWidget* _tmp9_;
	SpitPublishingDialogPaneGeometryOptions geometry_options = 0;
	SpitPublishingDialogPane* _tmp10_;
	SpitPublishingDialogPaneGeometryOptions _tmp11_;
	SpitPublishingDialogPaneGeometryOptions _tmp12_;
	SpitPublishingDialogPaneGeometryOptions _tmp14_;
	SpitPublishingDialogPane* _tmp15_;
	SpitPublishingDialogPane* _tmp16_;
	SpitPublishingDialogPane* _tmp17_;
#line 538 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_if_fail (PUBLISHING_UI_IS_PUBLISHING_DIALOG (self));
#line 538 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_if_fail (SPIT_PUBLISHING_IS_DIALOG_PANE (pane));
#line 539 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_debug ("PublishingUI.vala:539: PublishingDialog: install_pane( ): invoked.");
#line 541 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = self->priv->active_pane;
#line 541 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if (_tmp0_ != NULL) {
#line 3313 "PublishingUI.c"
		SpitPublishingDialogPane* _tmp1_;
		GtkBox* _tmp2_;
		SpitPublishingDialogPane* _tmp3_;
		GtkWidget* _tmp4_;
		GtkWidget* _tmp5_;
#line 542 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		g_debug ("PublishingUI.vala:542: PublishingDialog: install_pane( ): a pane is al" \
"ready installed; removing it.");
#line 544 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp1_ = self->priv->active_pane;
#line 544 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		spit_publishing_dialog_pane_on_pane_uninstalled (_tmp1_);
#line 545 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp2_ = self->priv->central_area_layouter;
#line 545 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp3_ = self->priv->active_pane;
#line 545 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp4_ = spit_publishing_dialog_pane_get_widget (_tmp3_);
#line 545 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp5_ = _tmp4_;
#line 545 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		gtk_container_remove (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, gtk_container_get_type (), GtkContainer), _tmp5_);
#line 545 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_g_object_unref0 (_tmp5_);
#line 3337 "PublishingUI.c"
	}
#line 548 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp6_ = self->priv->central_area_layouter;
#line 548 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp7_ = pane;
#line 548 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp8_ = spit_publishing_dialog_pane_get_widget (_tmp7_);
#line 548 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp9_ = _tmp8_;
#line 548 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_box_pack_start (_tmp6_, _tmp9_, TRUE, TRUE, (guint) 0);
#line 548 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (_tmp9_);
#line 549 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	gtk_widget_show_all (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_widget_get_type (), GtkWidget));
#line 551 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp10_ = pane;
#line 551 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp11_ = spit_publishing_dialog_pane_get_preferred_geometry (_tmp10_);
#line 551 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	geometry_options = _tmp11_;
#line 553 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp12_ = geometry_options;
#line 553 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if ((_tmp12_ & SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_EXTENDED_SIZE) != 0) {
#line 554 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		publishing_ui_publishing_dialog_set_large_window_mode (self);
#line 3365 "PublishingUI.c"
	} else {
		SpitPublishingDialogPaneGeometryOptions _tmp13_;
#line 555 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		_tmp13_ = geometry_options;
#line 555 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		if ((_tmp13_ & SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_COLOSSAL_SIZE) != 0) {
#line 556 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			publishing_ui_publishing_dialog_set_colossal_window_mode (self);
#line 3374 "PublishingUI.c"
		} else {
#line 558 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
			publishing_ui_publishing_dialog_set_standard_window_mode (self);
#line 3378 "PublishingUI.c"
		}
	}
#line 560 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp14_ = geometry_options;
#line 560 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	if ((_tmp14_ & SPIT_PUBLISHING_DIALOG_PANE_GEOMETRY_OPTIONS_RESIZABLE) != 0) {
#line 561 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		publishing_ui_publishing_dialog_set_free_sizable_window_mode (self);
#line 3387 "PublishingUI.c"
	} else {
#line 563 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
		publishing_ui_publishing_dialog_clear_free_sizable_window_mode (self);
#line 3391 "PublishingUI.c"
	}
#line 565 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp15_ = pane;
#line 565 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp16_ = _g_object_ref0 (_tmp15_);
#line 565 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->active_pane);
#line 565 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv->active_pane = _tmp16_;
#line 566 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp17_ = pane;
#line 566 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	spit_publishing_dialog_pane_on_pane_installed (_tmp17_);
#line 3405 "PublishingUI.c"
}


gint publishing_ui_publishing_dialog_run (PublishingUIPublishingDialog* self) {
	gint result = 0;
	gint _result_ = 0;
	gint _tmp0_;
#line 569 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_return_val_if_fail (PUBLISHING_UI_IS_PUBLISHING_DIALOG (self), 0);
#line 570 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	publishing_ui_publishing_dialog_on_service_changed (self);
#line 572 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_tmp0_ = gtk_dialog_run (G_TYPE_CHECK_INSTANCE_CAST (self, gtk_dialog_get_type (), GtkDialog));
#line 572 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_result_ = _tmp0_;
#line 574 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->host);
#line 574 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv->host = NULL;
#line 576 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	result = _result_;
#line 576 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	return result;
#line 3429 "PublishingUI.c"
}


static void publishing_ui_publishing_dialog_class_init (PublishingUIPublishingDialogClass * klass) {
#line 137 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	publishing_ui_publishing_dialog_parent_class = g_type_class_peek_parent (klass);
#line 137 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	g_type_class_add_private (klass, sizeof (PublishingUIPublishingDialogPrivate));
#line 137 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	G_OBJECT_CLASS (klass)->finalize = publishing_ui_publishing_dialog_finalize;
#line 3440 "PublishingUI.c"
}


static void publishing_ui_publishing_dialog_instance_init (PublishingUIPublishingDialog * self) {
#line 137 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv = PUBLISHING_UI_PUBLISHING_DIALOG_GET_PRIVATE (self);
#line 3447 "PublishingUI.c"
}


static void publishing_ui_publishing_dialog_finalize (GObject * obj) {
	PublishingUIPublishingDialog * self;
#line 137 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, PUBLISHING_UI_TYPE_PUBLISHING_DIALOG, PublishingUIPublishingDialog);
#line 152 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->service_selector_box_model);
#line 153 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->service_selector_box);
#line 154 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->central_area_layouter);
#line 155 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->close_cancel_button);
#line 156 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->active_pane);
#line 157 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	self->priv->publishables = (_vala_array_free (self->priv->publishables, self->priv->publishables_length1, (GDestroyNotify) g_object_unref), NULL);
#line 158 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	_g_object_unref0 (self->priv->host);
#line 159 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	spit_pluggable_info_destroy (&self->priv->info);
#line 137 "/home/jens/Source/shotwell/src/publishing/PublishingUI.vala"
	G_OBJECT_CLASS (publishing_ui_publishing_dialog_parent_class)->finalize (obj);
#line 3473 "PublishingUI.c"
}


GType publishing_ui_publishing_dialog_get_type (void) {
	static volatile gsize publishing_ui_publishing_dialog_type_id__volatile = 0;
	if (g_once_init_enter (&publishing_ui_publishing_dialog_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (PublishingUIPublishingDialogClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) publishing_ui_publishing_dialog_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (PublishingUIPublishingDialog), 0, (GInstanceInitFunc) publishing_ui_publishing_dialog_instance_init, NULL };
		GType publishing_ui_publishing_dialog_type_id;
		publishing_ui_publishing_dialog_type_id = g_type_register_static (gtk_dialog_get_type (), "PublishingUIPublishingDialog", &g_define_type_info, 0);
		g_once_init_leave (&publishing_ui_publishing_dialog_type_id__volatile, publishing_ui_publishing_dialog_type_id);
	}
	return publishing_ui_publishing_dialog_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



